@@ -213,6 +213,8 @@ template_g_ci <- function(dataname,
 #' To learn more please refer to the vignette
 #' `vignette("transform-module-output", package = "teal")` or the [`teal::teal_transform_module()`] documentation.
 #'
+#' @inheritSection teal::example_module Reporting
+#'
 #' @examplesShinylive
 #' library(teal.modules.clinical)
 #' interactive <- function() TRUE
@@ -223,6 +225,8 @@ template_g_ci <- function(dataname,
 #'
 #' data <- teal_data()
 #' data <- within(data, {
+#'   library(teal.modules.clinical)
+#'   library(dplyr)
 #'   ADSL <- tmc_ex_adsl
 #'   ADLB <- tmc_ex_adlb
 #' })
@@ -360,10 +364,6 @@ ui_g_ci <- function(id, ...) {
   teal.widgets::standard_layout(
     output = teal.widgets::plot_with_settings_ui(id = ns("myplot")),
     encoding = tags$div(
-      ### Reporter
-      teal.reporter::add_card_button_ui(ns("add_reporter"), label = "Add Report Card"),
-      tags$br(), tags$br(),
-      ###
       tags$label("Encodings", class = "text-primary"), tags$br(),
       teal.transform::datanames_input(args[c("x_var", "y_var", "color")]),
       teal.transform::data_extract_ui(
@@ -397,9 +397,6 @@ ui_g_ci <- function(id, ...) {
       ),
       ui_decorate_teal_data(ns("decorator"), decorators = select_decorators(args$decorators, "plot"))
     ),
-    forms = tagList(
-      teal.widgets::verbatim_popup_ui(ns("rcode"), "Show R code")
-    ),
     pre_output = args$pre_output,
     post_output = args$post_output
   )
@@ -408,8 +405,6 @@ ui_g_ci <- function(id, ...) {
 #' @keywords internal
 srv_g_ci <- function(id,
                      data,
-                     reporter,
-                     filter_panel_api,
                      x_var,
                      y_var,
                      color,
@@ -418,8 +413,6 @@ srv_g_ci <- function(id,
                      plot_width,
                      ggplot2_args,
                      decorators) {
-  with_reporter <- !missing(reporter) && inherits(reporter, "Reporter")
-  with_filter <- !missing(filter_panel_api) && inherits(filter_panel_api, "FilterPanelAPI")
   checkmate::assert_class(data, "reactive")
   checkmate::assert_class(isolate(data()), "teal_data")
 
@@ -454,8 +447,13 @@ srv_g_ci <- function(id,
     )
 
     anl_q <- reactive({
-      data() %>%
-        teal.code::eval_code(as.expression(anl_inputs()$expr))
+      obj <- data()
+      teal.reporter::teal_card(obj) <-
+        c(
+          teal.reporter::teal_card(obj),
+          teal.reporter::teal_card("## Module's output(s)")
+        )
+      obj %>% teal.code::eval_code(as.expression(anl_inputs()$expr))
     })
 
     all_q <- reactive({
@@ -504,7 +502,9 @@ srv_g_ci <- function(id,
         conf_level = as.numeric(input$conf_level),
         ggplot2_args = ggplot2_args
       )
-      teal.code::eval_code(anl_q(), list_calls)
+      obj <- anl_q()
+      teal.reporter::teal_card(obj) <- c(teal.reporter::teal_card(obj), "### Plot")
+      teal.code::eval_code(obj, list_calls)
     })
 
     decorated_plot_q <- srv_decorate_teal_data(
@@ -516,14 +516,6 @@ srv_g_ci <- function(id,
     # Outputs to render.
     plot_r <- reactive(decorated_plot_q()[["plot"]])
 
-    # Render R code
-    source_code_r <- reactive(teal.code::get_code(req(decorated_plot_q())))
-    teal.widgets::verbatim_popup_srv(
-      id = "rcode",
-      verbatim_content = source_code_r,
-      title = label
-    )
-
     pws <- teal.widgets::plot_with_settings_srv(
       id = "myplot",
       plot_r = plot_r,
@@ -531,27 +523,6 @@ srv_g_ci <- function(id,
       width = plot_width
     )
 
-    ### REPORTER
-    if (with_reporter) {
-      card_fun <- function(comment, label) {
-        card <- teal::report_card_template(
-          title = "CI Plot",
-          label = label,
-          description = "Confidence Interval Plot",
-          with_filter = with_filter,
-          filter_panel_api = filter_panel_api
-        )
-        card$append_text("Plot", "header3")
-        card$append_plot(plot_r(), dim = pws$dim())
-        if (!comment == "") {
-          card$append_text("Comment", "header3")
-          card$append_text(comment)
-        }
-        card$append_src(source_code_r())
-        card
-      }
-      teal.reporter::add_card_button_srv("add_reporter", reporter = reporter, card_fun = card_fun)
-    }
-    ###
+    set_chunk_dims(pws, decorated_plot_q)
   })
 }
