@@ -261,6 +261,8 @@ template_forest_tte <- function(dataname = "ANL",
 #' To learn more please refer to the vignette
 #' `vignette("transform-module-output", package = "teal")` or the [`teal::teal_transform_module()`] documentation.
 #'
+#' @inheritSection teal::example_module Reporting
+#'
 #' @examplesShinylive
 #' library(teal.modules.clinical)
 #' interactive <- function() TRUE
@@ -268,10 +270,12 @@ template_forest_tte <- function(dataname = "ANL",
 #'
 #' @examples
 #' library(nestcolor)
-#' library(dplyr)
 #'
 #' data <- teal_data()
 #' data <- within(data, {
+#'   library(teal.modules.clinical)
+#'   library(formatters)
+#'   library(dplyr)
 #'   ADSL <- tmc_ex_adsl
 #'   ADTTE <- tmc_ex_adtte
 #'   ADSL$RACE <- droplevels(ADSL$RACE) %>% with_label("Race")
@@ -444,10 +448,6 @@ ui_g_forest_tte <- function(id, ...) {
   teal.widgets::standard_layout(
     output = teal.widgets::plot_with_settings_ui(id = ns("myplot")),
     encoding = tags$div(
-      ### Reporter
-      teal.reporter::add_card_button_ui(ns("add_reporter"), label = "Add Report Card"),
-      tags$br(), tags$br(),
-      ###
       tags$label("Encodings", class = "text-primary"), tags$br(),
       teal.transform::datanames_input(a[c("arm_var", "paramcd", "subgroup_var", "strata_var", "aval_var", "cnsr_var")]),
       teal.transform::data_extract_ui(
@@ -528,9 +528,6 @@ ui_g_forest_tte <- function(id, ...) {
         )
       )
     ),
-    forms = tagList(
-      teal.widgets::verbatim_popup_ui(ns("rcode"), button_label = "Show R code")
-    ),
     pre_output = a$pre_output,
     post_output = a$post_output
   )
@@ -539,8 +536,6 @@ ui_g_forest_tte <- function(id, ...) {
 #' @keywords internal
 srv_g_forest_tte <- function(id,
                              data,
-                             reporter,
-                             filter_panel_api,
                              dataname,
                              parentname,
                              arm_var,
@@ -558,8 +553,6 @@ srv_g_forest_tte <- function(id,
                              plot_width,
                              ggplot2_args,
                              decorators) {
-  with_reporter <- !missing(reporter) && inherits(reporter, "Reporter")
-  with_filter <- !missing(filter_panel_api) && inherits(filter_panel_api, "FilterPanelAPI")
   checkmate::assert_class(data, "reactive")
   checkmate::assert_class(isolate(data()), "teal_data")
 
@@ -622,9 +615,15 @@ srv_g_forest_tte <- function(id,
     )
 
     anl_q <- reactive({
-      data() %>%
-        teal.code::eval_code(as.expression(anl_inputs()$expr)) %>%
-        teal.code::eval_code(as.expression(adsl_inputs()$expr))
+      obj <- data()
+      teal.reporter::teal_card(obj) <-
+        c(
+          teal.reporter::teal_card(obj),
+          teal.reporter::teal_card("## Module's output(s)")
+        )
+      obj %>%
+        teal.code::eval_code(code = as.expression(anl_inputs()$expr)) %>%
+        teal.code::eval_code(code = as.expression(adsl_inputs()$expr))
     })
 
     validate_checks <- reactive({
@@ -717,7 +716,9 @@ srv_g_forest_tte <- function(id,
         font_size = input$font_size,
         ggplot2_args = ggplot2_args
       )
-      teal.code::eval_code(anl_q(), as.expression(unlist(my_calls)))
+      obj <- anl_q()
+      teal.reporter::teal_card(obj) <- c(teal.reporter::teal_card(obj), "### Table and Plot")
+      teal.code::eval_code(obj, as.expression(unlist(my_calls)))
     })
 
     # Outputs to render.
@@ -725,10 +726,19 @@ srv_g_forest_tte <- function(id,
       id = "decorator",
       data = all_q,
       decorators = select_decorators(decorators, "plot"),
-      expr = {
-        table
-        plot
-      }
+      expr = reactive({
+        substitute(
+          cowplot::plot_grid(
+            table,
+            plot,
+            align = "h",
+            axis = "tblr",
+            rel_widths = c(1 - input_rel_width_forest / 100, input_rel_width_forest / 100)
+          ),
+          env = list(input_rel_width_forest = input$rel_width_forest)
+        )
+      }),
+      expr_is_reactive = TRUE
     )
     plot_r <- reactive({
       cowplot::plot_grid(
@@ -747,34 +757,6 @@ srv_g_forest_tte <- function(id,
       width = plot_width
     )
 
-    # Render R code
-    source_code_r <- reactive(teal.code::get_code(req(decorated_all_q())))
-    teal.widgets::verbatim_popup_srv(
-      id = "rcode",
-      verbatim_content = source_code_r,
-      title = label
-    )
-
-    ### REPORTER
-    if (with_reporter) {
-      card_fun <- function(comment, label) {
-        card <- teal::report_card_template(
-          title = "Forest Survival Plot",
-          label = label,
-          with_filter = with_filter,
-          filter_panel_api = filter_panel_api
-        )
-        card$append_text("Plot", "header3")
-        card$append_plot(plot_r(), dim = pws$dim())
-        if (!comment == "") {
-          card$append_text("Comment", "header3")
-          card$append_text(comment)
-        }
-        card$append_src(source_code_r())
-        card
-      }
-      teal.reporter::add_card_button_srv("add_reporter", reporter = reporter, card_fun = card_fun)
-    }
-    ###
+    set_chunk_dims(pws, decorated_all_q)
   })
 }
