@@ -273,6 +273,8 @@ template_abnormality_by_worst_grade <- function(parentname, # nolint: object_len
 #' To learn more please refer to the vignette
 #' `vignette("transform-module-output", package = "teal")` or the [`teal::teal_transform_module()`] documentation.
 #'
+#' @inheritSection teal::example_module Reporting
+#'
 #' @export
 #'
 #' @examplesShinylive
@@ -435,10 +437,6 @@ ui_t_abnormality_by_worst_grade <- function(id, ...) { # nolint: object_length.
   teal.widgets::standard_layout(
     output = teal.widgets::white_small_well(teal.widgets::table_with_settings_ui(ns("table"))),
     encoding = tags$div(
-      ### Reporter
-      teal.reporter::add_card_button_ui(ns("add_reporter"), label = "Add Report Card"),
-      tags$br(), tags$br(),
-      ###
       tags$label("Encodings", class = "text-primary"), tags$br(),
       teal.transform::datanames_input(
         a[c(
@@ -507,9 +505,6 @@ ui_t_abnormality_by_worst_grade <- function(id, ...) { # nolint: object_length.
         )
       )
     ),
-    forms = tagList(
-      teal.widgets::verbatim_popup_ui(ns("rcode"), button_label = "Show R code")
-    ),
     pre_output = a$pre_output,
     post_output = a$post_output
   )
@@ -518,8 +513,6 @@ ui_t_abnormality_by_worst_grade <- function(id, ...) { # nolint: object_length.
 #' @keywords internal
 srv_t_abnormality_by_worst_grade <- function(id, # nolint: object_length.
                                              data,
-                                             reporter,
-                                             filter_panel_api,
                                              dataname,
                                              parentname,
                                              id_var,
@@ -535,8 +528,6 @@ srv_t_abnormality_by_worst_grade <- function(id, # nolint: object_length.
                                              label,
                                              basic_table_args,
                                              decorators) {
-  with_reporter <- !missing(reporter) && inherits(reporter, "Reporter")
-  with_filter <- !missing(filter_panel_api) && inherits(filter_panel_api, "FilterPanelAPI")
   checkmate::assert_class(data, "reactive")
   checkmate::assert_class(shiny::isolate(data()), "teal_data")
 
@@ -598,7 +589,13 @@ srv_t_abnormality_by_worst_grade <- function(id, # nolint: object_length.
     )
 
     anl_q <- reactive({
-      data() %>%
+      obj <- data()
+      teal.reporter::teal_card(obj) <-
+        c(
+          teal.reporter::teal_card(obj),
+          teal.reporter::teal_card("## Module's output(s)")
+        )
+      obj %>%
         teal.code::eval_code(as.expression(anl_inputs()$expr)) %>%
         teal.code::eval_code(as.expression(adsl_inputs()$expr))
     })
@@ -694,7 +691,9 @@ srv_t_abnormality_by_worst_grade <- function(id, # nolint: object_length.
         basic_table_args = basic_table_args
       )
 
-      teal.code::eval_code(merged$anl_q(), as.expression(unlist(my_calls)))
+      obj <- merged$anl_q()
+      teal.reporter::teal_card(obj) <- c(teal.reporter::teal_card(obj), "### Table")
+      teal.code::eval_code(obj, as.expression(unlist(my_calls)))
     })
 
     decorated_table_q <- srv_decorate_teal_data(
@@ -712,35 +711,6 @@ srv_t_abnormality_by_worst_grade <- function(id, # nolint: object_length.
       table_r = table_r
     )
 
-    # Render R code.
-    source_code_r <- reactive(teal.code::get_code(req(decorated_table_q())))
-    teal.widgets::verbatim_popup_srv(
-      id = "rcode",
-      verbatim_content = source_code_r,
-      title = label
-    )
-
-    ### REPORTER
-    if (with_reporter) {
-      card_fun <- function(comment, label) {
-        card <- teal::report_card_template(
-          title = "Laboratory Test Results Table",
-          label = label,
-          description = "Laboratory test results with highest grade post-baseline Table",
-          with_filter = with_filter,
-          filter_panel_api = filter_panel_api
-        )
-        card$append_text("Table", "header3")
-        card$append_table(table_r())
-        if (!comment == "") {
-          card$append_text("Comment", "header3")
-          card$append_text(comment)
-        }
-        card$append_src(source_code_r())
-        card
-      }
-      teal.reporter::add_card_button_srv("add_reporter", reporter = reporter, card_fun = card_fun)
-    }
-    ###
+    decorated_table_q
   })
 }
