@@ -385,6 +385,8 @@ template_coxreg_m <- function(dataname,
 #' To learn more please refer to the vignette
 #' `vignette("transform-module-output", package = "teal")` or the [`teal::teal_transform_module()`] documentation.
 #'
+#' @inheritSection teal::example_module Reporting
+#'
 #' @examplesShinylive
 #' library(teal.modules.clinical)
 #' interactive <- function() TRUE
@@ -614,10 +616,6 @@ ui_t_coxreg <- function(id, ...) {
   teal.widgets::standard_layout(
     output = teal.widgets::white_small_well(teal.widgets::table_with_settings_ui(ns("table"))),
     encoding = tags$div(
-      ### Reporter
-      teal.reporter::add_card_button_ui(ns("add_reporter"), label = "Add Report Card"),
-      tags$br(), tags$br(),
-      ###
       radioButtons(
         ns("type"),
         label = tags$label("Type of Regression:", class = "text-primary"),
@@ -728,9 +726,6 @@ ui_t_coxreg <- function(id, ...) {
       ),
       ui_decorate_teal_data(ns("decorator"), decorators = select_decorators(a$decorators, "table"))
     ),
-    forms = tagList(
-      teal.widgets::verbatim_popup_ui(ns("rcode"), button_label = "Show R code")
-    ),
     pre_output = a$pre_output,
     post_output = a$post_output
   )
@@ -739,8 +734,6 @@ ui_t_coxreg <- function(id, ...) {
 #' @keywords internal
 srv_t_coxreg <- function(id,
                          data,
-                         reporter,
-                         filter_panel_api,
                          dataname,
                          parentname,
                          arm_var,
@@ -754,8 +747,6 @@ srv_t_coxreg <- function(id,
                          na_level,
                          basic_table_args,
                          decorators) {
-  with_reporter <- !missing(reporter) && inherits(reporter, "Reporter")
-  with_filter <- !missing(filter_panel_api) && inherits(filter_panel_api, "FilterPanelAPI")
   checkmate::assert_class(data, "reactive")
   checkmate::assert_class(shiny::isolate(data()), "teal_data")
 
@@ -864,7 +855,15 @@ srv_t_coxreg <- function(id,
       merge_function = "dplyr::inner_join"
     )
 
-    anl_q <- reactive(teal.code::eval_code(data(), as.expression(anl_inputs()$expr)))
+    anl_q <- reactive({
+      obj <- data()
+      teal.reporter::teal_card(obj) <-
+        c(
+          teal.reporter::teal_card(obj),
+          teal.reporter::teal_card("## Module's output(s)")
+        )
+      teal.code::eval_code(obj, as.expression(anl_inputs()$expr))
+    })
 
     merged <- list(
       anl_input_r = anl_inputs,
@@ -1061,7 +1060,9 @@ srv_t_coxreg <- function(id,
           unlist(input$buckets$Comp), merged$anl_input_r(),
           paramcd, multivariate, all_basic_table_args
         )
-        teal.code::eval_code(merged$anl_q(), as.expression(expr))
+        obj <- merged$anl_q()
+        teal.reporter::teal_card(obj) <- c(teal.reporter::teal_card(obj), "### Table")
+        teal.code::eval_code(obj, as.expression(expr))
       } else {
         main_title <- paste("Cox Regression for", paramcd)
         subtitle <- ifelse(length(strata_var) == 0, "", paste("Stratified by", paste(strata_var, collapse = " and ")))
@@ -1073,7 +1074,9 @@ srv_t_coxreg <- function(id,
           )
         )
 
-        merged$anl_q() %>%
+        obj <- merged$anl_q()
+        teal.reporter::teal_card(obj) <- c(teal.reporter::teal_card(obj), "### Table")
+        obj %>%
           teal.code::eval_code(quote(table <- list())) %>%
           teal.code::eval_code(
             as.expression(unlist(lapply(
@@ -1110,7 +1113,6 @@ srv_t_coxreg <- function(id,
     })
 
 
-
     decorated_table_q <- srv_decorate_teal_data(
       id = "decorator",
       data = all_q,
@@ -1128,34 +1130,6 @@ srv_t_coxreg <- function(id,
       table_r = table_r
     )
 
-    # Render R code
-    source_code_r <- reactive(teal.code::get_code(req(decorated_table_q())))
-    teal.widgets::verbatim_popup_srv(
-      id = "rcode",
-      verbatim_content = source_code_r,
-      title = label
-    )
-
-    ### REPORTER
-    if (with_reporter) {
-      card_fun <- function(comment, label) {
-        card <- teal::report_card_template(
-          title = "Cox Regression Table",
-          label = label,
-          with_filter = with_filter,
-          filter_panel_api = filter_panel_api
-        )
-        card$append_text("Table", "header3")
-        card$append_table(table_r())
-        if (!comment == "") {
-          card$append_text("Comment", "header3")
-          card$append_text(comment)
-        }
-        card$append_src(source_code_r())
-        card
-      }
-      teal.reporter::add_card_button_srv("add_reporter", reporter = reporter, card_fun = card_fun)
-    }
-    ###
+    decorated_table_q
   })
 }
