@@ -480,6 +480,8 @@ template_events <- function(dataname,
 #' To learn more please refer to the vignette
 #' `vignette("transform-module-output", package = "teal")` or the [`teal::teal_transform_module()`] documentation.
 #'
+#' @inheritSection teal::example_module Reporting
+#'
 #' @examplesShinylive
 #' library(teal.modules.clinical)
 #' interactive <- function() TRUE
@@ -612,10 +614,6 @@ ui_t_events_byterm <- function(id, ...) {
       teal.widgets::table_with_settings_ui(ns("table"))
     ),
     encoding = tags$div(
-      ### Reporter
-      teal.reporter::add_card_button_ui(ns("add_reporter"), label = "Add Report Card"),
-      tags$br(), tags$br(),
-      ###
       tags$label("Encodings", class = "text-primary"), tags$br(),
       teal.transform::datanames_input(a[c("arm_var", "hlt", "llt")]),
       teal.transform::data_extract_ui(
@@ -638,48 +636,47 @@ ui_t_events_byterm <- function(id, ...) {
       ),
       checkboxInput(ns("add_total"), "Add All Patients columns", value = a$add_total),
       ui_decorate_teal_data(ns("decorator"), decorators = select_decorators(a$decorators, "table")),
-      bslib::accordion_panel(
-        "Additional table settings",
+      bslib::accordion(
         open = TRUE,
-        checkboxInput(
-          ns("drop_arm_levels"),
-          label = "Drop columns not in filtered analysis dataset",
-          value = a$drop_arm_levels
-        ),
-        selectInput(
-          inputId = ns("sort_criteria"),
-          label = "Sort Criteria",
-          choices = c(
-            "Decreasing frequency" = "freq_desc",
-            "Alphabetically" = "alpha"
+        bslib::accordion_panel(
+          "Additional table settings",
+          checkboxInput(
+            ns("drop_arm_levels"),
+            label = "Drop columns not in filtered analysis dataset",
+            value = a$drop_arm_levels
           ),
-          selected = a$sort_criteria,
-          multiple = FALSE
-        ),
-        helpText(tags$strong("Pruning Options:")),
-        numericInput(
-          inputId = ns("prune_freq"),
-          label = "Minimum Incidence Rate(%) in any of the treatment groups",
-          value = a$prune_freq,
-          min = 0,
-          max = 100,
-          step = 1,
-          width = "100%"
-        ),
-        numericInput(
-          inputId = ns("prune_diff"),
-          label = "Minimum Difference Rate(%) between any of the treatment groups",
-          value = a$prune_diff,
-          min = 0,
-          max = 100,
-          step = 1,
-          width = "100%"
+          selectInput(
+            inputId = ns("sort_criteria"),
+            label = "Sort Criteria",
+            choices = c(
+              "Decreasing frequency" = "freq_desc",
+              "Alphabetically" = "alpha"
+            ),
+            selected = a$sort_criteria,
+            multiple = FALSE
+          ),
+          helpText(tags$strong("Pruning Options:")),
+          numericInput(
+            inputId = ns("prune_freq"),
+            label = "Minimum Incidence Rate(%) in any of the treatment groups",
+            value = a$prune_freq,
+            min = 0,
+            max = 100,
+            step = 1,
+            width = "100%"
+          ),
+          numericInput(
+            inputId = ns("prune_diff"),
+            label = "Minimum Difference Rate(%) between any of the treatment groups",
+            value = a$prune_diff,
+            min = 0,
+            max = 100,
+            step = 1,
+            width = "100%"
+          )
         )
       )
     ),
-    forms = tagList(
-      teal.widgets::verbatim_popup_ui(ns("rcode"), button_label = "Show R code")
-    ),
     pre_output = a$pre_output,
     post_output = a$post_output
   )
@@ -688,8 +685,6 @@ ui_t_events_byterm <- function(id, ...) {
 #' @keywords internal
 srv_t_events_byterm <- function(id,
                                 data,
-                                filter_panel_api,
-                                reporter,
                                 dataname,
                                 parentname,
                                 event_type,
@@ -704,8 +699,6 @@ srv_t_events_byterm <- function(id,
                                 sort_freq_col,
                                 basic_table_args,
                                 decorators) {
-  with_reporter <- !missing(reporter) && inherits(reporter, "Reporter")
-  with_filter <- !missing(filter_panel_api) && inherits(filter_panel_api, "FilterPanelAPI")
   checkmate::assert_class(data, "reactive")
   checkmate::assert_class(shiny::isolate(data()), "teal_data")
 
@@ -755,7 +748,13 @@ srv_t_events_byterm <- function(id,
     )
 
     anl_q <- reactive({
-      data() %>%
+      obj <- data()
+      teal.reporter::teal_card(obj) <-
+        c(
+          teal.reporter::teal_card(obj),
+          teal.reporter::teal_card("## Module's output(s)")
+        )
+      obj %>%
         teal.code::eval_code(as.expression(anl_inputs()$expr)) %>%
         teal.code::eval_code(as.expression(adsl_inputs()$expr))
     })
@@ -833,7 +832,9 @@ srv_t_events_byterm <- function(id,
         basic_table_args = basic_table_args
       )
 
-      teal.code::eval_code(merged$anl_q(), as.expression(unlist(my_calls)))
+      obj <- merged$anl_q()
+      teal.reporter::teal_card(obj) <- c(teal.reporter::teal_card(obj), "### Table")
+      teal.code::eval_code(obj, as.expression(unlist(my_calls)))
     })
 
     table_renamed_q <- reactive({
@@ -842,7 +843,6 @@ srv_t_events_byterm <- function(id,
         table <- pruned_and_sorted_result
       })
     })
-
     decorated_table_q <- srv_decorate_teal_data(
       id = "decorator",
       data = table_renamed_q,
@@ -858,34 +858,6 @@ srv_t_events_byterm <- function(id,
       table_r = table_r
     )
 
-    # Render R code.
-    source_code_r <- reactive(teal.code::get_code(req(decorated_table_q())))
-    teal.widgets::verbatim_popup_srv(
-      id = "rcode",
-      verbatim_content = source_code_r,
-      title = label
-    )
-
-    ### REPORTER
-    if (with_reporter) {
-      card_fun <- function(comment, label) {
-        card <- teal::report_card_template(
-          title = "Events by Term Table",
-          label = label,
-          with_filter = with_filter,
-          filter_panel_api = filter_panel_api
-        )
-        card$append_text("Table", "header3")
-        card$append_table(table_r())
-        if (!comment == "") {
-          card$append_text("Comment", "header3")
-          card$append_text(comment)
-        }
-        card$append_src(source_code_r())
-        card
-      }
-      teal.reporter::add_card_button_srv("add_reporter", reporter = reporter, card_fun = card_fun)
-    }
-    ###
+    decorated_table_q
   })
 }
