@@ -70,6 +70,8 @@ template_prior_medication <- function(dataname = "ANL",
 #'
 #' @inherit module_arguments return
 #'
+#' @inheritSection teal::example_module Reporting
+#'
 #' @examplesShinylive
 #' library(teal.modules.clinical)
 #' interactive <- function() TRUE
@@ -199,10 +201,6 @@ ui_t_prior_medication <- function(id, ...) {
       DT::DTOutput(outputId = ns("prior_medication_table"))
     ),
     encoding = tags$div(
-      ### Reporter
-      teal.reporter::add_card_button_ui(ns("add_reporter"), label = "Add Report Card"),
-      tags$br(), tags$br(),
-      ###
       tags$label("Encodings", class = "text-primary"), tags$br(),
       teal.transform::datanames_input(ui_args[c("atirel", "cmdecod", "cmindc", "cmstdy")]),
       teal.widgets::optionalSelectInput(
@@ -236,9 +234,6 @@ ui_t_prior_medication <- function(id, ...) {
         is_single_dataset = is_single_dataset_value
       )
     ),
-    forms = tagList(
-      teal.widgets::verbatim_popup_ui(ns("rcode"), button_label = "Show R code")
-    ),
     pre_output = ui_args$pre_output,
     post_output = ui_args$post_output
   )
@@ -247,8 +242,6 @@ ui_t_prior_medication <- function(id, ...) {
 #' @keywords internal
 srv_t_prior_medication <- function(id,
                                    data,
-                                   reporter,
-                                   filter_panel_api,
                                    dataname,
                                    parentname,
                                    patient_col,
@@ -257,8 +250,6 @@ srv_t_prior_medication <- function(id,
                                    cmindc,
                                    cmstdy,
                                    label) {
-  with_reporter <- !missing(reporter) && inherits(reporter, "Reporter")
-  with_filter <- !missing(filter_panel_api) && inherits(filter_panel_api, "FilterPanelAPI")
   checkmate::assert_class(data, "reactive")
   checkmate::assert_class(shiny::isolate(data()), "teal_data")
 
@@ -321,7 +312,13 @@ srv_t_prior_medication <- function(id,
     )
 
     anl_q <- reactive({
-      data() %>%
+      obj <- data()
+      teal.reporter::teal_card(obj) <-
+        c(
+          teal.reporter::teal_card(obj),
+          teal.reporter::teal_card("## Module's output(s)")
+        )
+      obj %>%
         teal.code::eval_code(as.expression(anl_inputs()$expr))
     })
 
@@ -337,7 +334,7 @@ srv_t_prior_medication <- function(id,
         cmstdy = input[[extract_input("cmstdy", dataname)]]
       )
 
-      anl_q() %>%
+      obj <- anl_q() %>%
         teal.code::eval_code(
           substitute(
             expr = {
@@ -347,8 +344,9 @@ srv_t_prior_medication <- function(id,
               patient_id = patient_id()
             )
           )
-        ) %>%
-        teal.code::eval_code(as.expression(unlist(my_calls)))
+        )
+      teal.reporter::teal_card(obj) <- c(teal.reporter::teal_card(obj), "### Table")
+      obj %>% teal.code::eval_code(as.expression(unlist(my_calls)))
     })
 
     # Outputs to render.
@@ -367,37 +365,6 @@ srv_t_prior_medication <- function(id,
 
     output$prior_medication_table <- DT::renderDataTable(expr = table_r()$html)
 
-    # Render R code.
-    source_code_r <- reactive(teal.code::get_code(req(all_q())))
-    teal.widgets::verbatim_popup_srv(
-      id = "rcode",
-      verbatim_content = source_code_r,
-      title = label
-    )
-
-    if (with_reporter) {
-      card_fun <- function(comment, label) {
-        card <- teal::report_card_template(
-          title = "Patient Prior Medication Table",
-          label = label,
-          with_filter = with_filter,
-          filter_panel_api = filter_panel_api
-        )
-        card$append_text("Table", "header3")
-        if (nrow(table_r()$report) == 0L) {
-          card$append_text("No data available for table.")
-        } else {
-          card$append_table(table_r()$report)
-        }
-        if (!comment == "") {
-          card$append_text("Comment", "header3")
-          card$append_text(comment)
-        }
-        card$append_src(source_code_r())
-        card
-      }
-      teal.reporter::add_card_button_srv("add_reporter", reporter = reporter, card_fun = card_fun)
-    }
-    ###
+    all_q
   })
 }
