@@ -27,7 +27,6 @@ template_summary <- function(dataname,
                              denominator = c("N", "n", "omit"),
                              drop_arm_levels = TRUE,
                              basic_table_args = teal.widgets::basic_table_args()) {
-
   checkmate::assert_string(dataname)
   checkmate::assert_string(parentname)
   checkmate::assert_character(arm_var, min.len = 1, max.len = 2)
@@ -52,18 +51,27 @@ template_summary <- function(dataname,
   # Data processing
   data_list <- list()
 
-  data_list <- add_expr(
-    data_list,
-    substitute(
-      expr = anl <- df %>%
-        tern::df_explicit_na(omit_columns = setdiff(names(df), c(sum_vars)), na_level = na_str),
-      env = list(
-        df = as.name(dataname),
-        sum_vars = sum_vars,
-        na_str = na_level
+  if (!na.rm) {
+    data_list <- add_expr(
+      data_list,
+      substitute(
+        expr = anl <- tern::df_explicit_na(df, omit_columns = setdiff(names(df), c(sum_vars)), na_level = na_level),
+        env = list(
+          df = as.name(dataname),
+          sum_vars = sum_vars,
+          na_level = na_level
+        )
       )
     )
-  )
+  } else {
+    data_list <- add_expr(
+      data_list,
+      substitute(
+        expr = anl <- df,
+        env = list(df = as.name(dataname))
+      )
+    )
+  }
 
   prepare_arm_levels_call <- lapply(arm_var, function(x) {
     prepare_arm_levels(
@@ -74,28 +82,26 @@ template_summary <- function(dataname,
     )
   })
   data_list <- Reduce(add_expr, prepare_arm_levels_call, init = data_list)
-
-  data_list <- add_expr(
-    data_list,
-    substitute(
-      expr = parentname <- tern::df_explicit_na(parentname, na_level = na_str),
-      env = list(
-        parentname = as.name(parentname),
-        na_str = na_level
-      )
-    )
-  )
-
   y$data <- bracket_expr(data_list)
 
+  # Only add the footer about NA if needed
+  if (na.rm) {
+    module_table_args <- teal.widgets::basic_table_args(
+      show_colcounts = TRUE,
+      main_footer =
+        sprintf(
+          "N represents the number of unique subject IDs such that the variable has NA (%s) values.",
+          na_level
+        )
+    )
+  } else {
+    module_table_args <- teal.widgets::basic_table_args(show_colcounts = TRUE)
+  }
+
   parsed_basic_table_args <- teal.widgets::parse_basic_table_args(
     teal.widgets::resolve_basic_table_args(
       user_table = basic_table_args,
-      module_table = teal.widgets::basic_table_args(
-        show_colcounts = TRUE,
-        main_footer =
-          "n represents the number of unique subject IDs such that the variable has non-NA values."
-      )
+      module_table = module_table_args
     )
   )
 
@@ -151,7 +157,7 @@ template_summary <- function(dataname,
           vars = sum_vars,
           var_labels = sum_var_labels,
           show_labels = "visible",
-          na.rm = na.rm,
+          na_rm = na.rm,
           na_str = na_level,
           denom = denom,
           .stats = stats
@@ -238,6 +244,8 @@ template_summary <- function(dataname,
 #' To learn more please refer to the vignette
 #' `vignette("transform-module-output", package = "teal")` or the [`teal::teal_transform_module()`] documentation.
 #'
+#' @inheritSection teal::example_module Reporting
+#'
 #' @examplesShinylive
 #' library(teal.modules.clinical)
 #' interactive <- function() TRUE
@@ -360,10 +368,6 @@ ui_summary <- function(id, ...) {
   teal.widgets::standard_layout(
     output = teal.widgets::white_small_well(teal.widgets::table_with_settings_ui(ns("table"))),
     encoding = tags$div(
-      ### Reporter
-      teal.reporter::add_card_button_ui(ns("add_reporter"), label = "Add Report Card"),
-      tags$br(), tags$br(),
-      ###
       tags$label("Encodings", class = "text-primary"), tags$br(),
       teal.transform::datanames_input(a[c("arm_var", "summarize_vars")]),
       teal.transform::data_extract_ui(
@@ -429,9 +433,6 @@ ui_summary <- function(id, ...) {
       ),
       ui_decorate_teal_data(ns("decorator"), decorators = select_decorators(a$decorators, "table"))
     ),
-    forms = tagList(
-      teal.widgets::verbatim_popup_ui(ns("rcode"), button_label = "Show R code")
-    ),
     pre_output = a$pre_output,
     post_output = a$post_output
   )
@@ -440,8 +441,6 @@ ui_summary <- function(id, ...) {
 #' @keywords internal
 srv_summary <- function(id,
                         data,
-                        reporter,
-                        filter_panel_api,
                         dataname,
                         parentname,
                         arm_var,
@@ -454,8 +453,6 @@ srv_summary <- function(id,
                         label,
                         basic_table_args,
                         decorators) {
-  with_reporter <- !missing(reporter) && inherits(reporter, "Reporter")
-  with_filter <- !missing(filter_panel_api) && inherits(filter_panel_api, "FilterPanelAPI")
   checkmate::assert_class(data, "reactive")
   checkmate::assert_class(shiny::isolate(data()), "teal_data")
   moduleServer(id, function(input, output, session) {
@@ -492,7 +489,13 @@ srv_summary <- function(id,
     )
 
     anl_q <- reactive({
-      data() %>%
+      obj <- data()
+      teal.reporter::teal_card(obj) <-
+        c(
+          teal.reporter::teal_card(obj),
+          teal.reporter::teal_card("## Module's output(s)")
+        )
+      obj %>%
         teal.code::eval_code(as.expression(anl_inputs()$expr)) %>%
         teal.code::eval_code(as.expression(adsl_inputs()$expr))
     })
@@ -567,12 +570,12 @@ srv_summary <- function(id,
     all_q <- reactive({
       validate_checks()
 
-      summarize_vars <- merged$anl_input_r()$columns_source$summarize_vars
+      summarize_vars <- as.vector(merged$anl_input_r()$columns_source$summarize_vars)
       var_labels <- teal.data::col_labels(data()[[dataname]][, summarize_vars, drop = FALSE])
 
       arm_var_labels <- NULL
+      arm_vars <- as.vector(merged$anl_input_r()$columns_source$arm_var)
       if (show_arm_var_labels) {
-        arm_vars <- merged$anl_input_r()$columns_source$arm_var
         arm_var_labels <- teal.data::col_labels(data()[[dataname]][, arm_vars, drop = FALSE], fill = TRUE)
       }
 
@@ -593,7 +596,9 @@ srv_summary <- function(id,
         basic_table_args = basic_table_args
       )
 
-      teal.code::eval_code(merged$anl_q(), as.expression(unlist(my_calls)))
+      obj <- merged$anl_q()
+      teal.reporter::teal_card(obj) <- c(teal.reporter::teal_card(obj), "### Table")
+      teal.code::eval_code(obj, as.expression(unlist(my_calls)))
     })
 
     # Decoration of table output.
@@ -609,34 +614,6 @@ srv_summary <- function(id,
 
     teal.widgets::table_with_settings_srv(id = "table", table_r = table_r)
 
-    # Render R code.
-    source_code_r <- reactive(teal.code::get_code(req(decorated_table_q())))
-    teal.widgets::verbatim_popup_srv(
-      id = "rcode",
-      verbatim_content = source_code_r,
-      title = label
-    )
-
-    ### REPORTER
-    if (with_reporter) {
-      card_fun <- function(comment, label) {
-        card <- teal::report_card_template(
-          title = "Summary Table",
-          label = label,
-          with_filter = with_filter,
-          filter_panel_api = filter_panel_api
-        )
-        card$append_text("Table", "header3")
-        card$append_table(table_r())
-        if (!comment == "") {
-          card$append_text("Comment", "header3")
-          card$append_text(comment)
-        }
-        card$append_src(source_code_r())
-        card
-      }
-      teal.reporter::add_card_button_srv("add_reporter", reporter = reporter, card_fun = card_fun)
-    }
-    ###
+    decorated_table_q
   })
 }
