@@ -1,4 +1,5 @@
-.onLoad <- function(libname, pkgname) { # nolint
+.onLoad <- function(libname, pkgname) {
   teal.logger::register_logger(namespace = "teal.modules.clinical")
+  teal.logger::register_handlers("teal.modules.clinical")
   tern::set_default_na_str("<Missing>")
 }
