@@ -18,25 +18,27 @@ app_driver_tm_a_gee <- function() {
   teal.data::join_keys(data) <- teal.data::default_cdisc_join_keys[names(data)]
 
   init_teal_app_driver(
-    data = data,
-    modules = tm_a_gee(
-      label = "GEE",
-      dataname = "ADQS",
-      parentname = "ADSL",
-      aval_var = teal.transform::choices_selected("AVALBIN", fixed = TRUE),
-      id_var = teal.transform::choices_selected(c("USUBJID", "SUBJID"), "USUBJID"),
-      arm_var = teal.transform::choices_selected(c("ARM", "ARMCD"), "ARM"),
-      visit_var = teal.transform::choices_selected(c("AVISIT", "AVISITN"), "AVISIT"),
-      paramcd = teal.transform::choices_selected(
-        choices = teal.transform::value_choices(data[["ADQS"]], "PARAMCD", "PARAM"),
-        selected = "FKSI-FWB"
-      ),
-      cov_var = teal.transform::choices_selected(c("BASE", "AGE", "SEX", "BASE:AVISIT"), NULL),
-      conf_level = teal.transform::choices_selected(c(0.95, 0.9, 0.8, -1), 0.95, keep_order = TRUE),
-      arm_ref_comp = NULL,
-      pre_output = NULL,
-      post_output = NULL,
-      basic_table_args = teal.widgets::basic_table_args()
+    teal::init(
+      data = data,
+      modules = tm_a_gee(
+        label = "GEE",
+        dataname = "ADQS",
+        parentname = "ADSL",
+        aval_var = teal.transform::choices_selected("AVALBIN", fixed = TRUE),
+        id_var = teal.transform::choices_selected(c("USUBJID", "SUBJID"), "USUBJID"),
+        arm_var = teal.transform::choices_selected(c("ARM", "ARMCD"), "ARM"),
+        visit_var = teal.transform::choices_selected(c("AVISIT", "AVISITN"), "AVISIT"),
+        paramcd = teal.transform::choices_selected(
+          choices = teal.transform::value_choices(data[["ADQS"]], "PARAMCD", "PARAM"),
+          selected = "FKSI-FWB"
+        ),
+        cov_var = teal.transform::choices_selected(c("BASE", "AGE", "SEX", "BASE:AVISIT"), NULL),
+        conf_level = teal.transform::choices_selected(c(0.95, 0.9, 0.8, -1), 0.95, keep_order = TRUE),
+        arm_ref_comp = NULL,
+        pre_output = NULL,
+        post_output = NULL,
+        basic_table_args = teal.widgets::basic_table_args()
+      )
     )
   )
 }
@@ -48,7 +50,7 @@ testthat::test_that("e2e - tm_a_gee: Module initializes in teal without errors a
   app_driver <- app_driver_tm_a_gee()
   app_driver$expect_no_shiny_error()
   app_driver$expect_no_validation_error()
-  testthat::expect_true(app_driver$is_visible(app_driver$active_module_element("table-table-with-settings")))
+  testthat::expect_true(app_driver$is_visible(app_driver$namespaces(TRUE)$module("table-table-with-settings")))
   app_driver$stop()
 })
 
@@ -98,7 +100,7 @@ testthat::test_that(
 
     testthat::expect_equal(app_driver$get_active_module_input("cor_struct"), "unstructured")
 
-    radio_buttons <- app_driver$active_module_element_text("output_table")
+    radio_buttons <- app_driver$namespaces(TRUE)$module("output_table")
     testthat::expect_match(
       radio_buttons,
       "Output Type.*LS means.*Covariance.*Coefficients",
@@ -135,7 +137,7 @@ testthat::test_that("e2e - tm_a_gee: Deselection of id_var throws validation err
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text("id_var-dataset_ADQS_singleextract-select_input > div > span"),
+    app_driver$namespaces(TRUE)$module("id_var-dataset_ADQS_singleextract-select_input > div > span"),
     "A Subject identifier is required"
   )
   app_driver$stop()
@@ -166,7 +168,7 @@ testthat::test_that("e2e - tm_a_gee: Deselection of arm_var throws validation er
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text("arm_var-dataset_ADSL_singleextract-select_input > div > span"),
+    app_driver$namespaces(TRUE)$module("arm_var-dataset_ADSL_singleextract-select_input > div > span"),
     "A treatment variable is required"
   )
   app_driver$stop()
@@ -200,7 +202,7 @@ testthat::test_that("e2e - tm_a_gee: Deselection of visit_var throws validation
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text("visit_var-dataset_ADQS_singleextract-select_input > div > span"),
+    app_driver$namespaces(TRUE)$module("visit_var-dataset_ADQS_singleextract-select_input > div > span"),
     "A visit variable is required"
   )
   app_driver$stop()
@@ -230,7 +232,7 @@ testthat::test_that("e2e - tm_a_gee: Deselection of paramcd throws validation er
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text("paramcd-dataset_ADQS_singleextract-filter1-vals_input > div > span"),
+    app_driver$namespaces(TRUE)$module("paramcd-dataset_ADQS_singleextract-filter1-vals_input > div > span"),
     "An endpoint is required"
   )
   app_driver$stop()
@@ -277,7 +279,7 @@ testthat::test_that("e2e - tm_a_gee: Selection of conf_level out of [0,1] range
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text("conf_level_input > div > span"),
+    app_driver$namespaces(TRUE)$module("conf_level_input > div > span"),
     "Confidence level must be between 0 and 1"
   )
   app_driver$stop()
@@ -291,7 +293,7 @@ testthat::test_that("e2e - tm_a_gee: Deselection of conf_level throws validation
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text("conf_level_input > div > span"),
+    app_driver$namespaces(TRUE)$module("conf_level_input > div > span"),
     "Please choose a confidence level"
   )
   app_driver$stop()
