@@ -25,43 +25,45 @@ app_driver_tm_a_mmrm <- function(fit_model = TRUE) {
   arm_var <- choices_selected(c("ARM", "ARMCD"), "ARM")
 
   app_driver <- init_teal_app_driver(
-    data = data,
-    modules = tm_a_mmrm(
-      label = "MMRM",
-      dataname = "ADQS",
-      parentname = ifelse(inherits(arm_var, "data_extract_spec"),
-        teal.transform::datanames_input(arm_var), "ADSL"
-      ),
-      aval_var = choices_selected(c("AVAL", "CHG"), "AVAL"),
-      id_var = choices_selected(c("USUBJID", "SUBJID"), "USUBJID"),
-      arm_var = arm_var,
-      visit_var = choices_selected(c("AVISIT", "AVISITN"), "AVISIT"),
-      arm_ref_comp = arm_ref_comp,
-      paramcd = choices_selected(
-        choices = value_choices(data[["ADQS"]], "PARAMCD", "PARAM"),
-        selected = "FKSI-FWB"
-      ),
-      cov_var = choices_selected(c("BASE", "AGE", "SEX", "BASE:AVISIT"), NULL),
-      method = teal.transform::choices_selected(c(
-        "Satterthwaite", "Kenward-Roger",
-        "Kenward-Roger-Linear"
-      ), "Satterthwaite", keep_order = TRUE),
-      conf_level = teal.transform::choices_selected(c(0.95, 0.9, 0.8), 0.95,
-        keep_order =
-          TRUE
-      ),
-      plot_height = c(700L, 200L, 2000L),
-      plot_width = NULL,
-      total_label = default_total_label(),
-      pre_output = NULL,
-      post_output = NULL,
-      basic_table_args = teal.widgets::basic_table_args(),
-      ggplot2_args = teal.widgets::ggplot2_args()
+    teal::init(
+      data = data,
+      modules = tm_a_mmrm(
+        label = "MMRM",
+        dataname = "ADQS",
+        parentname = ifelse(inherits(arm_var, "data_extract_spec"),
+          teal.transform::datanames_input(arm_var), "ADSL"
+        ),
+        aval_var = choices_selected(c("AVAL", "CHG"), "AVAL"),
+        id_var = choices_selected(c("USUBJID", "SUBJID"), "USUBJID"),
+        arm_var = arm_var,
+        visit_var = choices_selected(c("AVISIT", "AVISITN"), "AVISIT"),
+        arm_ref_comp = arm_ref_comp,
+        paramcd = choices_selected(
+          choices = value_choices(data[["ADQS"]], "PARAMCD", "PARAM"),
+          selected = "FKSI-FWB"
+        ),
+        cov_var = choices_selected(c("BASE", "AGE", "SEX", "BASE:AVISIT"), NULL),
+        method = teal.transform::choices_selected(c(
+          "Satterthwaite", "Kenward-Roger",
+          "Kenward-Roger-Linear"
+        ), "Satterthwaite", keep_order = TRUE),
+        conf_level = teal.transform::choices_selected(c(0.95, 0.9, 0.8), 0.95,
+          keep_order =
+            TRUE
+        ),
+        plot_height = c(700L, 200L, 2000L),
+        plot_width = NULL,
+        total_label = default_total_label(),
+        pre_output = NULL,
+        post_output = NULL,
+        basic_table_args = teal.widgets::basic_table_args(),
+        ggplot2_args = teal.widgets::ggplot2_args()
+      )
     ),
     timeout = 30000
   )
   if (fit_model) {
-    app_driver$click(selector = app_driver$active_module_element("button_start"))
+    app_driver$click(selector = app_driver$namespaces(TRUE)$module("button_start"))
     app_driver$wait_for_idle()
   }
   app_driver
@@ -86,7 +88,7 @@ testthat::test_that(
     app_driver$expect_no_shiny_error()
     app_driver$expect_no_validation_error()
 
-    null_text <- app_driver$active_module_element_text("null_input_msg")
+    null_text <- app_driver$namespaces(TRUE)$module("null_input_msg")
 
     testthat::expect_match(null_text, "Please first specify 'Model Settings' and press 'Fit Model'")
 
@@ -168,7 +170,7 @@ testthat::test_that(
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_a_mmrm()
 
-    app_driver$click(selector = app_driver$active_module_element("button_start"))
+    app_driver$click(selector = app_driver$namespaces(TRUE)$module("button_start"))
     app_driver$wait_for_idle()
     app_driver$expect_no_validation_error()
 
@@ -190,7 +192,7 @@ testthat::test_that(
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_a_mmrm()
 
-    app_driver$click(selector = app_driver$active_module_element("button_start"))
+    app_driver$click(selector = app_driver$namespaces(TRUE)$module("button_start"))
     app_driver$wait_for_idle()
     app_driver$expect_no_validation_error()
 
@@ -233,7 +235,7 @@ testthat::test_that(
     skip_if_too_deep(5)
     app_driver <- app_driver_tm_a_mmrm()
 
-    app_driver$click(selector = app_driver$active_module_element("button_start"))
+    app_driver$click(selector = app_driver$namespaces(TRUE)$module("button_start"))
     app_driver$wait_for_idle()
     app_driver$expect_no_validation_error()
 
@@ -278,7 +280,7 @@ for (func in output_functions) {
       }
 
       testthat::expect_match(
-        app_driver$active_module_element_text(
+        app_driver$namespaces(TRUE)$module(
           sprintf(
             "%s .shiny-validation-message",
             ns_des_input("aval_var", "ADQS", "select_input")
@@ -314,7 +316,7 @@ for (func in output_functions) {
       }
 
       testthat::expect_match(
-        app_driver$active_module_element_text(
+        app_driver$namespaces(TRUE)$module(
           sprintf(
             "%s .shiny-validation-message",
             ns_des_input("paramcd", "ADQS", "filter1-vals_input")
@@ -350,7 +352,7 @@ for (func in output_functions) {
       }
 
       testthat::expect_match(
-        app_driver$active_module_element_text(
+        app_driver$namespaces(TRUE)$module(
           sprintf(
             "%s .shiny-validation-message",
             ns_des_input("visit_var", "ADQS", "select_input")
@@ -386,7 +388,7 @@ for (func in output_functions) {
       }
 
       testthat::expect_match(
-        app_driver$active_module_element_text(
+        app_driver$namespaces(TRUE)$module(
           sprintf(
             "%s .shiny-validation-message",
             ns_des_input("arm_var", "ADSL", "select_input")
@@ -422,7 +424,7 @@ for (func in output_functions) {
       }
 
       testthat::expect_match(
-        app_driver$active_module_element_text(
+        app_driver$namespaces(TRUE)$module(
           sprintf(
             "%s .shiny-validation-message",
             ns_des_input("id_var", "ADQS", "select_input")
@@ -458,7 +460,7 @@ for (func in output_functions) {
       }
 
       testthat::expect_match(
-        app_driver$active_module_element_text(
+        app_driver$namespaces(TRUE)$module(
           sprintf(
             "%s .shiny-validation-message",
             "conf_level_input"
@@ -530,7 +532,7 @@ for (func in output_functions) {
         }
 
         app_driver$set_active_module_input(input_name, input_list[[input_name]])
-        app_driver$click(selector = app_driver$active_module_element("button_start"))
+        app_driver$click(selector = app_driver$namespaces(TRUE)$module("button_start"))
         app_driver$wait_for_idle()
         app_driver$expect_no_validation_error()
 
