@@ -7,66 +7,68 @@ app_driver_tm_g_ci <- function() {
   teal.data::join_keys(data) <- teal.data::default_cdisc_join_keys[names(data)]
 
   init_teal_app_driver(
-    data = data,
-    modules = tm_g_ci(
-      label = "Confidence Interval Plot",
-      x_var = teal.transform::data_extract_spec(
-        dataname = "ADSL",
-        select = teal.transform::select_spec(
-          choices = c("ARMCD", "BMRKR2"),
-          selected = c("ARMCD"),
-          multiple = FALSE,
-          fixed = FALSE
-        )
-      ),
-      y_var = teal.transform::data_extract_spec(
-        dataname = "ADLB",
-        filter = list(
-          teal.transform::filter_spec(
-            vars = "PARAMCD",
-            choices = c("ALT", "CRP", "IGA"),
-            selected = "ALT",
+    teal::init(
+      data = data,
+      modules = tm_g_ci(
+        label = "Confidence Interval Plot",
+        x_var = teal.transform::data_extract_spec(
+          dataname = "ADSL",
+          select = teal.transform::select_spec(
+            choices = c("ARMCD", "BMRKR2"),
+            selected = c("ARMCD"),
             multiple = FALSE,
-            label = "Select lab:"
-          ),
-          teal.transform::filter_spec(
-            vars = "AVISIT",
-            choices = c(
-              "SCREENING", "BASELINE", "WEEK 1 DAY 8", "WEEK 2 DAY 15",
-              "WEEK 3 DAY 22", "WEEK 4 DAY 29", "WEEK 5 DAY 36"
-            ),
-            selected = "SCREENING",
-            multiple = FALSE,
-            label = "Select visit:"
+            fixed = FALSE
           )
         ),
-        select = teal.transform::select_spec(
-          label = "Analyzed Value",
-          choices = c("AVAL", "CHG", "CHG2"),
-          selected = "AVAL",
-          multiple = FALSE,
-          fixed = FALSE
-        )
-      ),
-      color = teal.transform::data_extract_spec(
-        dataname = "ADSL",
-        select = teal.transform::select_spec(
-          label = "Color by variable",
-          choices = c("SEX", "STRATA1", "STRATA2"),
-          selected = c("STRATA1"),
-          multiple = FALSE,
-          fixed = FALSE
-        )
-      ),
-      stat = c("mean", "median"),
-      conf_level = teal.transform::choices_selected(c(0.95, 0.9, 0.8), 0.95,
-        keep_order = TRUE
-      ),
-      plot_height = c(700L, 200L, 2000L),
-      plot_width = NULL,
-      pre_output = NULL,
-      post_output = NULL,
-      ggplot2_args = teal.widgets::ggplot2_args()
+        y_var = teal.transform::data_extract_spec(
+          dataname = "ADLB",
+          filter = list(
+            teal.transform::filter_spec(
+              vars = "PARAMCD",
+              choices = c("ALT", "CRP", "IGA"),
+              selected = "ALT",
+              multiple = FALSE,
+              label = "Select lab:"
+            ),
+            teal.transform::filter_spec(
+              vars = "AVISIT",
+              choices = c(
+                "SCREENING", "BASELINE", "WEEK 1 DAY 8", "WEEK 2 DAY 15",
+                "WEEK 3 DAY 22", "WEEK 4 DAY 29", "WEEK 5 DAY 36"
+              ),
+              selected = "SCREENING",
+              multiple = FALSE,
+              label = "Select visit:"
+            )
+          ),
+          select = teal.transform::select_spec(
+            label = "Analyzed Value",
+            choices = c("AVAL", "CHG", "CHG2"),
+            selected = "AVAL",
+            multiple = FALSE,
+            fixed = FALSE
+          )
+        ),
+        color = teal.transform::data_extract_spec(
+          dataname = "ADSL",
+          select = teal.transform::select_spec(
+            label = "Color by variable",
+            choices = c("SEX", "STRATA1", "STRATA2"),
+            selected = c("STRATA1"),
+            multiple = FALSE,
+            fixed = FALSE
+          )
+        ),
+        stat = c("mean", "median"),
+        conf_level = teal.transform::choices_selected(c(0.95, 0.9, 0.8), 0.95,
+          keep_order = TRUE
+        ),
+        plot_height = c(700L, 200L, 2000L),
+        plot_width = NULL,
+        pre_output = NULL,
+        post_output = NULL,
+        ggplot2_args = teal.widgets::ggplot2_args()
+      )
     )
   )
 }
@@ -163,7 +165,7 @@ testthat::test_that("e2e - tm_g_ci: Deselecting x_var column throws validation e
   testthat::expect_identical(app_driver$get_active_module_plot_output("myplot"), character(0))
   app_driver$expect_validation_error()
   testthat::expect_identical(
-    app_driver$active_module_element_text("x_var-dataset_ADSL_singleextract-select_input > div > span"),
+    app_driver$namespaces(TRUE)$module("x_var-dataset_ADSL_singleextract-select_input > div > span"),
     "Select a treatment (x axis)"
   )
   app_driver$stop()
@@ -192,7 +194,7 @@ testthat::test_that("e2e - tm_g_ci: Deselecting y_var column throws validation e
   app_driver$set_active_module_input("y_var-dataset_ADLB_singleextract-select", character(0))
   testthat::expect_identical(app_driver$get_active_module_plot_output("myplot"), character(0))
   testthat::expect_identical(
-    app_driver$active_module_element_text("y_var-dataset_ADLB_singleextract-select_input > div > span"),
+    app_driver$namespaces(TRUE)$module("y_var-dataset_ADLB_singleextract-select_input > div > span"),
     "Select an analysis value (y axis)"
   )
   app_driver$expect_validation_error()
@@ -225,7 +227,7 @@ testthat::test_that("e2e - tm_g_ci: Deselecting PARAMCD filter value throws vali
   app_driver$set_active_module_input("y_var-dataset_ADLB_singleextract-filter1-vals", character(0))
   testthat::expect_identical(app_driver$get_active_module_plot_output("myplot"), character(0))
   testthat::expect_identical(
-    app_driver$active_module_element_text("y_var-dataset_ADLB_singleextract-filter1-vals_input > div > span"),
+    app_driver$namespaces(TRUE)$module("y_var-dataset_ADLB_singleextract-filter1-vals_input > div > span"),
     "Please select the filters."
   )
   app_driver$expect_validation_error()
@@ -250,7 +252,7 @@ testthat::test_that("e2e - tm_g_ci: Deselecting AVISIT filter value throws valid
   app_driver$set_active_module_input("y_var-dataset_ADLB_singleextract-filter2-vals", character(0))
   testthat::expect_identical(app_driver$get_active_module_plot_output("myplot"), character(0))
   testthat::expect_identical(
-    app_driver$active_module_element_text("y_var-dataset_ADLB_singleextract-filter2-vals_input > div > span"),
+    app_driver$namespaces(TRUE)$module("y_var-dataset_ADLB_singleextract-filter2-vals_input > div > span"),
     "Please select the filters."
   )
   app_driver$expect_validation_error()
