@@ -13,51 +13,53 @@ app_driver_tm_g_ipp <- function() {
   teal.data::join_keys(data) <- teal.data::default_cdisc_join_keys[names(data)]
 
   init_teal_app_driver(
-    data = data,
-    modules = tm_g_ipp(
-      label = "Individual Patient Plot",
-      dataname = "ADLB",
-      parentname = "ADSL",
-      arm_var = teal.transform::choices_selected(
-        teal.transform::value_choices(data[["ADLB"]], "ARMCD"),
-        "ARM A"
-      ),
-      paramcd = teal.transform::choices_selected(
-        teal.transform::value_choices(data[["ADLB"]], "PARAMCD"),
-        "ALT"
-      ),
-      aval_var = teal.transform::choices_selected(
-        teal.transform::variable_choices(data[["ADLB"]], c("AVAL", "CHG")),
-        "AVAL"
-      ),
-      avalu_var = teal.transform::choices_selected(
-        teal.transform::variable_choices(data[["ADLB"]], c("AVALU")),
-        "AVALU",
-        fixed = TRUE
-      ),
-      id_var = teal.transform::choices_selected(
-        teal.transform::variable_choices(data[["ADLB"]], c("USUBJID")),
-        "USUBJID",
-        fixed = TRUE
-      ),
-      visit_var = teal.transform::choices_selected(
-        teal.transform::variable_choices(data[["ADLB"]], c("AVISIT", "ATOXGR")),
-        "AVISIT"
-      ),
-      baseline_var = teal.transform::choices_selected(
-        teal.transform::variable_choices(data[["ADLB"]], c("BASE")),
-        "BASE",
-        fixed = TRUE
-      ),
-      add_baseline_hline = FALSE,
-      separate_by_obs = FALSE,
-      suppress_legend = FALSE,
-      add_avalu = TRUE,
-      plot_height = c(1200L, 400L, 5000L),
-      plot_width = NULL,
-      pre_output = NULL,
-      post_output = NULL,
-      ggplot2_args = teal.widgets::ggplot2_args()
+    teal::init(
+      data = data,
+      modules = tm_g_ipp(
+        label = "Individual Patient Plot",
+        dataname = "ADLB",
+        parentname = "ADSL",
+        arm_var = teal.transform::choices_selected(
+          teal.transform::value_choices(data[["ADLB"]], "ARMCD"),
+          "ARM A"
+        ),
+        paramcd = teal.transform::choices_selected(
+          teal.transform::value_choices(data[["ADLB"]], "PARAMCD"),
+          "ALT"
+        ),
+        aval_var = teal.transform::choices_selected(
+          teal.transform::variable_choices(data[["ADLB"]], c("AVAL", "CHG")),
+          "AVAL"
+        ),
+        avalu_var = teal.transform::choices_selected(
+          teal.transform::variable_choices(data[["ADLB"]], c("AVALU")),
+          "AVALU",
+          fixed = TRUE
+        ),
+        id_var = teal.transform::choices_selected(
+          teal.transform::variable_choices(data[["ADLB"]], c("USUBJID")),
+          "USUBJID",
+          fixed = TRUE
+        ),
+        visit_var = teal.transform::choices_selected(
+          teal.transform::variable_choices(data[["ADLB"]], c("AVISIT", "ATOXGR")),
+          "AVISIT"
+        ),
+        baseline_var = teal.transform::choices_selected(
+          teal.transform::variable_choices(data[["ADLB"]], c("BASE")),
+          "BASE",
+          fixed = TRUE
+        ),
+        add_baseline_hline = FALSE,
+        separate_by_obs = FALSE,
+        suppress_legend = FALSE,
+        add_avalu = TRUE,
+        plot_height = c(1200L, 400L, 5000L),
+        plot_width = NULL,
+        pre_output = NULL,
+        post_output = NULL,
+        ggplot2_args = teal.widgets::ggplot2_args()
+      )
     )
   )
 }
@@ -154,7 +156,7 @@ testthat::test_that("e2e - tm_g_ipp: Deselecting arm_var column throws validatio
   app_driver$set_active_module_input("arm_var-dataset_ADSL_singleextract-filter1-vals", NULL)
   testthat::expect_identical(app_driver$get_active_module_plot_output("myplot"), character(0))
   testthat::expect_identical(
-    app_driver$active_module_element_text("arm_var-dataset_ADSL_singleextract-filter1-vals_input > div > span"),
+    app_driver$namespaces(TRUE)$module("arm_var-dataset_ADSL_singleextract-filter1-vals_input > div > span"),
     "Please select Arm filter."
   )
   app_driver$expect_validation_error()
@@ -184,7 +186,7 @@ testthat::test_that("e2e - tm_g_ipp: Deselecting paramcd throws validation error
   app_driver$set_active_module_input("paramcd-dataset_ADLB_singleextract-filter1-vals", NULL)
   testthat::expect_identical(app_driver$get_active_module_plot_output("myplot"), character(0))
   testthat::expect_identical(
-    app_driver$active_module_element_text("paramcd-dataset_ADLB_singleextract-filter1-vals_input > div > span"),
+    app_driver$namespaces(TRUE)$module("paramcd-dataset_ADLB_singleextract-filter1-vals_input > div > span"),
     "Please select Parameter filter."
   )
   app_driver$expect_validation_error()
@@ -214,7 +216,7 @@ testthat::test_that("e2e - tm_g_ipp: Deselecting visit_var throws validation err
   app_driver$set_active_module_input("visit_var-dataset_ADLB_singleextract-select", NULL)
   testthat::expect_identical(app_driver$get_active_module_plot_output("myplot"), character(0))
   testthat::expect_identical(
-    app_driver$active_module_element_text("visit_var-dataset_ADLB_singleextract-select_input > div > span"),
+    app_driver$namespaces(TRUE)$module("visit_var-dataset_ADLB_singleextract-select_input > div > span"),
     "A Timepoint Variable must be selected"
   )
   app_driver$expect_validation_error()
@@ -244,7 +246,7 @@ testthat::test_that("e2e - tm_g_ipp: Deselecting aval_var throws validation erro
   app_driver$set_active_module_input("aval_var-dataset_ADLB_singleextract-select", NULL)
   testthat::expect_identical(app_driver$get_active_module_plot_output("myplot"), character(0))
   testthat::expect_identical(
-    app_driver$active_module_element_text("aval_var-dataset_ADLB_singleextract-select_input > div > span"),
+    app_driver$namespaces(TRUE)$module("aval_var-dataset_ADLB_singleextract-select_input > div > span"),
     "A Parameter values over Time must be selected"
   )
   app_driver$expect_validation_error()
