@@ -27,59 +27,61 @@ app_driver_tm_g_pp_patient_timeline <- function() { # nolint object_length.
   teal.data::join_keys(data)["ADAE", "ADCM"] <- c("STUDYID", "USUBJID")
 
   init_teal_app_driver(
-    data = data,
-    modules = tm_g_pp_patient_timeline(
-      label = "Patient Timeline",
-      dataname_adae = "ADAE",
-      dataname_adcm = "ADCM",
-      parentname = "ADSL",
-      patient_col = "USUBJID",
-      plot_height = c(600L, 200L, 2000L),
-      cmdecod = teal.transform::choices_selected(
-        choices = teal.transform::variable_choices(data[["ADCM"]], c("CMDECOD", "CMCAT")),
-        selected = "CMDECOD"
-      ),
-      aeterm = teal.transform::choices_selected(
-        choices = teal.transform::variable_choices(data[["ADAE"]], c("AETERM", "AESOC")),
-        selected = "AETERM"
-      ),
-      aetime_start = teal.transform::choices_selected(
-        choices = teal.transform::variable_choices(data[["ADAE"]], c("ASTDTM", "TRTSDTM")),
-        selected = "ASTDTM"
-      ),
-      aetime_end = teal.transform::choices_selected(
-        choices = teal.transform::variable_choices(data[["ADAE"]], c("AENDTM", "EOSDT")),
-        selected = "AENDTM"
-      ),
-      dstime_start = teal.transform::choices_selected(
-        choices = teal.transform::variable_choices(data[["ADCM"]], c("CMASTDTM", "TRTEDTM")),
-        selected = "CMASTDTM"
-      ),
-      dstime_end = teal.transform::choices_selected(
-        choices = teal.transform::variable_choices(data[["ADCM"]], c("CMAENDTM", "TRTEDTM")),
-        selected = "CMAENDTM"
-      ),
-      aerelday_start = teal.transform::choices_selected(
-        choices = teal.transform::variable_choices(data[["ADAE"]], c("ASTDY", "AENDY")),
-        selected = "ASTDY"
-      ),
-      aerelday_end = teal.transform::choices_selected(
-        choices = teal.transform::variable_choices(data[["ADAE"]], c("AENDY", "ASTDY")),
-        selected = "AENDY"
-      ),
-      dsrelday_start = teal.transform::choices_selected(
-        choices = teal.transform::variable_choices(data[["ADCM"]], c("ASTDY", "AENDY")),
-        selected = "ASTDY"
-      ),
-      dsrelday_end = teal.transform::choices_selected(
-        choices = teal.transform::variable_choices(data[["ADCM"]], c("AENDY", "ASTDY")),
-        selected = "AENDY"
-      ),
-      font_size = c(12L, 12L, 25L),
-      plot_width = NULL,
-      pre_output = NULL,
-      post_output = NULL,
-      ggplot2_args = teal.widgets::ggplot2_args()
+    teal::init(
+      data = data,
+      modules = tm_g_pp_patient_timeline(
+        label = "Patient Timeline",
+        dataname_adae = "ADAE",
+        dataname_adcm = "ADCM",
+        parentname = "ADSL",
+        patient_col = "USUBJID",
+        plot_height = c(600L, 200L, 2000L),
+        cmdecod = teal.transform::choices_selected(
+          choices = teal.transform::variable_choices(data[["ADCM"]], c("CMDECOD", "CMCAT")),
+          selected = "CMDECOD"
+        ),
+        aeterm = teal.transform::choices_selected(
+          choices = teal.transform::variable_choices(data[["ADAE"]], c("AETERM", "AESOC")),
+          selected = "AETERM"
+        ),
+        aetime_start = teal.transform::choices_selected(
+          choices = teal.transform::variable_choices(data[["ADAE"]], c("ASTDTM", "TRTSDTM")),
+          selected = "ASTDTM"
+        ),
+        aetime_end = teal.transform::choices_selected(
+          choices = teal.transform::variable_choices(data[["ADAE"]], c("AENDTM", "EOSDT")),
+          selected = "AENDTM"
+        ),
+        dstime_start = teal.transform::choices_selected(
+          choices = teal.transform::variable_choices(data[["ADCM"]], c("CMASTDTM", "TRTEDTM")),
+          selected = "CMASTDTM"
+        ),
+        dstime_end = teal.transform::choices_selected(
+          choices = teal.transform::variable_choices(data[["ADCM"]], c("CMAENDTM", "TRTEDTM")),
+          selected = "CMAENDTM"
+        ),
+        aerelday_start = teal.transform::choices_selected(
+          choices = teal.transform::variable_choices(data[["ADAE"]], c("ASTDY", "AENDY")),
+          selected = "ASTDY"
+        ),
+        aerelday_end = teal.transform::choices_selected(
+          choices = teal.transform::variable_choices(data[["ADAE"]], c("AENDY", "ASTDY")),
+          selected = "AENDY"
+        ),
+        dsrelday_start = teal.transform::choices_selected(
+          choices = teal.transform::variable_choices(data[["ADCM"]], c("ASTDY", "AENDY")),
+          selected = "ASTDY"
+        ),
+        dsrelday_end = teal.transform::choices_selected(
+          choices = teal.transform::variable_choices(data[["ADCM"]], c("AENDY", "ASTDY")),
+          selected = "AENDY"
+        ),
+        font_size = c(12L, 12L, 25L),
+        plot_width = NULL,
+        pre_output = NULL,
+        post_output = NULL,
+        ggplot2_args = teal.widgets::ggplot2_args()
+      )
     )
   )
 }
@@ -178,10 +180,10 @@ testthat::test_that(
 
     testthat::expect_true(
       all(
-        app_driver$is_visible(app_driver$active_module_element("aerelday_start-dataset_ADAE_singleextract-select")),
-        app_driver$is_visible(app_driver$active_module_element("aerelday_end-dataset_ADAE_singleextract-select")),
-        app_driver$is_visible(app_driver$active_module_element("dsrelday_start-dataset_ADCM_singleextract-select")),
-        app_driver$is_visible(app_driver$active_module_element("dsrelday_end-dataset_ADCM_singleextract-select"))
+        app_driver$is_visible(app_driver$namespaces(TRUE)$module("aerelday_start-dataset_ADAE_singleextract-select")),
+        app_driver$is_visible(app_driver$namespaces(TRUE)$module("aerelday_end-dataset_ADAE_singleextract-select")),
+        app_driver$is_visible(app_driver$namespaces(TRUE)$module("dsrelday_start-dataset_ADCM_singleextract-select")),
+        app_driver$is_visible(app_driver$namespaces(TRUE)$module("dsrelday_end-dataset_ADCM_singleextract-select"))
       )
     )
 
@@ -189,10 +191,10 @@ testthat::test_that(
 
     testthat::expect_false(
       any(
-        app_driver$is_visible(app_driver$active_module_element("aerelday_start-dataset_ADAE_singleextract-select")),
-        app_driver$is_visible(app_driver$active_module_element("aerelday_end-dataset_ADAE_singleextract-select")),
-        app_driver$is_visible(app_driver$active_module_element("dsrelday_start-dataset_ADCM_singleextract-select")),
-        app_driver$is_visible(app_driver$active_module_element("dsrelday_end-dataset_ADCM_singleextract-select"))
+        app_driver$is_visible(app_driver$namespaces(TRUE)$module("aerelday_start-dataset_ADAE_singleextract-select")),
+        app_driver$is_visible(app_driver$namespaces(TRUE)$module("aerelday_end-dataset_ADAE_singleextract-select")),
+        app_driver$is_visible(app_driver$namespaces(TRUE)$module("dsrelday_start-dataset_ADCM_singleextract-select")),
+        app_driver$is_visible(app_driver$namespaces(TRUE)$module("dsrelday_end-dataset_ADCM_singleextract-select"))
       )
     )
 
@@ -210,10 +212,10 @@ testthat::test_that(
 
     testthat::expect_false(
       any(
-        app_driver$is_visible(app_driver$active_module_element("aetime_start-dataset_ADAE_singleextract-select")),
-        app_driver$is_visible(app_driver$active_module_element("aetime_end-dataset_ADAE_singleextract-select")),
-        app_driver$is_visible(app_driver$active_module_element("dstime_start-dataset_ADCM_singleextract-select")),
-        app_driver$is_visible(app_driver$active_module_element("dstime_end-dataset_ADCM_singleextract-select"))
+        app_driver$is_visible(app_driver$namespaces(TRUE)$module("aetime_start-dataset_ADAE_singleextract-select")),
+        app_driver$is_visible(app_driver$namespaces(TRUE)$module("aetime_end-dataset_ADAE_singleextract-select")),
+        app_driver$is_visible(app_driver$namespaces(TRUE)$module("dstime_start-dataset_ADCM_singleextract-select")),
+        app_driver$is_visible(app_driver$namespaces(TRUE)$module("dstime_end-dataset_ADCM_singleextract-select"))
       )
     )
 
@@ -221,10 +223,10 @@ testthat::test_that(
 
     testthat::expect_true(
       all(
-        app_driver$is_visible(app_driver$active_module_element("aetime_start-dataset_ADAE_singleextract-select")),
-        app_driver$is_visible(app_driver$active_module_element("aetime_end-dataset_ADAE_singleextract-select")),
-        app_driver$is_visible(app_driver$active_module_element("dstime_start-dataset_ADCM_singleextract-select")),
-        app_driver$is_visible(app_driver$active_module_element("dstime_end-dataset_ADCM_singleextract-select"))
+        app_driver$is_visible(app_driver$namespaces(TRUE)$module("aetime_start-dataset_ADAE_singleextract-select")),
+        app_driver$is_visible(app_driver$namespaces(TRUE)$module("aetime_end-dataset_ADAE_singleextract-select")),
+        app_driver$is_visible(app_driver$namespaces(TRUE)$module("dstime_start-dataset_ADCM_singleextract-select")),
+        app_driver$is_visible(app_driver$namespaces(TRUE)$module("dstime_end-dataset_ADCM_singleextract-select"))
       )
     )
 
@@ -258,7 +260,7 @@ testthat::test_that("e2e - tm_g_pp_patient_timeline: Deselecting patient_id colu
   app_driver$set_active_module_input("patient_id", NULL)
   testthat::expect_identical(app_driver$get_active_module_plot_output("patient_timeline_plot"), character(0))
   testthat::expect_identical(
-    app_driver$active_module_element_text("patient_id_input > div > span"),
+    app_driver$namespaces(TRUE)$module("patient_id_input > div > span"),
     "Please select a patient"
   )
   app_driver$expect_validation_error()
@@ -361,7 +363,7 @@ testthat::test_that(
     app_driver$set_active_module_input("aetime_start-dataset_ADAE_singleextract-select", NULL)
     testthat::expect_identical(app_driver$get_active_module_plot_output("myplot"), character(0))
     testthat::expect_identical(
-      app_driver$active_module_element_text("aetime_start-dataset_ADAE_singleextract-select_input > div > span"),
+      app_driver$namespaces(TRUE)$module("aetime_start-dataset_ADAE_singleextract-select_input > div > span"),
       "Please add AE start date."
     )
     app_driver$expect_validation_error()
@@ -399,7 +401,7 @@ testthat::test_that(
     app_driver$set_active_module_input("aetime_end-dataset_ADAE_singleextract-select", NULL)
     testthat::expect_identical(app_driver$get_active_module_plot_output("myplot"), character(0))
     testthat::expect_identical(
-      app_driver$active_module_element_text("aetime_end-dataset_ADAE_singleextract-select_input > div > span"),
+      app_driver$namespaces(TRUE)$module("aetime_end-dataset_ADAE_singleextract-select_input > div > span"),
       "Please add AE end date."
     )
     app_driver$expect_validation_error()
@@ -435,7 +437,7 @@ testthat::test_that(
     app_driver$set_active_module_input("aerelday_start-dataset_ADAE_singleextract-select", NULL)
     testthat::expect_identical(app_driver$get_active_module_plot_output("myplot"), character(0))
     testthat::expect_identical(
-      app_driver$active_module_element_text("aerelday_start-dataset_ADAE_singleextract-select_input > div > span"),
+      app_driver$namespaces(TRUE)$module("aerelday_start-dataset_ADAE_singleextract-select_input > div > span"),
       "Please add AE start date."
     )
     app_driver$expect_validation_error()
@@ -471,7 +473,7 @@ testthat::test_that(
     app_driver$set_active_module_input("aerelday_end-dataset_ADAE_singleextract-select", NULL)
     testthat::expect_identical(app_driver$get_active_module_plot_output("myplot"), character(0))
     testthat::expect_identical(
-      app_driver$active_module_element_text("aerelday_end-dataset_ADAE_singleextract-select_input > div > span"),
+      app_driver$namespaces(TRUE)$module("aerelday_end-dataset_ADAE_singleextract-select_input > div > span"),
       "Please add AE end date."
     )
     app_driver$expect_validation_error()
@@ -509,7 +511,7 @@ testthat::test_that(
     app_driver$set_active_module_input("dstime_start-dataset_ADCM_singleextract-select", NULL)
     testthat::expect_identical(app_driver$get_active_module_plot_output("myplot"), character(0))
     testthat::expect_identical(
-      app_driver$active_module_element_text("dstime_start-dataset_ADCM_singleextract-select_input > div > span"),
+      app_driver$namespaces(TRUE)$module("dstime_start-dataset_ADCM_singleextract-select_input > div > span"),
       "Please add Medication start date."
     )
     app_driver$expect_validation_error()
@@ -547,7 +549,7 @@ testthat::test_that(
     app_driver$set_active_module_input("dstime_end-dataset_ADCM_singleextract-select", NULL)
     testthat::expect_identical(app_driver$get_active_module_plot_output("myplot"), character(0))
     testthat::expect_identical(
-      app_driver$active_module_element_text("dstime_end-dataset_ADCM_singleextract-select_input > div > span"),
+      app_driver$namespaces(TRUE)$module("dstime_end-dataset_ADCM_singleextract-select_input > div > span"),
       "Please add Medication end date."
     )
     app_driver$expect_validation_error()
@@ -583,7 +585,7 @@ testthat::test_that(
     app_driver$set_active_module_input("dsrelday_start-dataset_ADCM_singleextract-select", NULL)
     testthat::expect_identical(app_driver$get_active_module_plot_output("myplot"), character(0))
     testthat::expect_identical(
-      app_driver$active_module_element_text("dsrelday_start-dataset_ADCM_singleextract-select_input > div > span"),
+      app_driver$namespaces(TRUE)$module("dsrelday_start-dataset_ADCM_singleextract-select_input > div > span"),
       "Please add Medication start date."
     )
     app_driver$expect_validation_error()
@@ -619,7 +621,7 @@ testthat::test_that(
     app_driver$set_active_module_input("dsrelday_end-dataset_ADCM_singleextract-select", NULL)
     testthat::expect_identical(app_driver$get_active_module_plot_output("myplot"), character(0))
     testthat::expect_identical(
-      app_driver$active_module_element_text("dsrelday_end-dataset_ADCM_singleextract-select_input > div > span"),
+      app_driver$namespaces(TRUE)$module("dsrelday_end-dataset_ADCM_singleextract-select_input > div > span"),
       "Please add Medication end date."
     )
     app_driver$expect_validation_error()
