@@ -19,39 +19,41 @@ app_driver_tm_t_coxreg <- function() {
   )
 
   init_teal_app_driver(
-    data = data,
-    modules = tm_t_coxreg(
-      label = "Cox Reg.",
-      dataname = "ADTTE",
-      parentname = "ADSL",
-      arm_var = teal.transform::choices_selected(c("ARM", "ARMCD", "ACTARMCD"), "ARM"),
-      arm_ref_comp = arm_ref_comp,
-      paramcd = teal.transform::choices_selected(
-        teal.transform::value_choices(data[["ADTTE"]], "PARAMCD", "PARAM"), "OS"
-      ),
-      strata_var = teal.transform::choices_selected(
-        c("COUNTRY", "STRATA1", "STRATA2"), "STRATA1"
-      ),
-      cov_var = teal.transform::choices_selected(
-        c("AGE", "BMRKR1", "BMRKR2", "REGION1"), "AGE"
-      ),
-      multivariate = TRUE,
-      aval_var = teal.transform::choices_selected(
-        teal.transform::variable_choices(data[["ADTTE"]], "AVAL"), "AVAL",
-        fixed = TRUE
-      ),
-      cnsr_var = teal.transform::choices_selected(
-        teal.transform::variable_choices(data[["ADTTE"]], "CNSR"), "CNSR",
-        fixed = TRUE
-      ),
-      na_level = default_na_str(),
-      conf_level = teal.transform::choices_selected(c(0.95, 0.9, 0.8), 0.95,
-        keep_order =
-          TRUE
-      ),
-      pre_output = NULL,
-      post_output = NULL,
-      basic_table_args = teal.widgets::basic_table_args()
+    teal::init(
+      data = data,
+      modules = tm_t_coxreg(
+        label = "Cox Reg.",
+        dataname = "ADTTE",
+        parentname = "ADSL",
+        arm_var = teal.transform::choices_selected(c("ARM", "ARMCD", "ACTARMCD"), "ARM"),
+        arm_ref_comp = arm_ref_comp,
+        paramcd = teal.transform::choices_selected(
+          teal.transform::value_choices(data[["ADTTE"]], "PARAMCD", "PARAM"), "OS"
+        ),
+        strata_var = teal.transform::choices_selected(
+          c("COUNTRY", "STRATA1", "STRATA2"), "STRATA1"
+        ),
+        cov_var = teal.transform::choices_selected(
+          c("AGE", "BMRKR1", "BMRKR2", "REGION1"), "AGE"
+        ),
+        multivariate = TRUE,
+        aval_var = teal.transform::choices_selected(
+          teal.transform::variable_choices(data[["ADTTE"]], "AVAL"), "AVAL",
+          fixed = TRUE
+        ),
+        cnsr_var = teal.transform::choices_selected(
+          teal.transform::variable_choices(data[["ADTTE"]], "CNSR"), "CNSR",
+          fixed = TRUE
+        ),
+        na_level = default_na_str(),
+        conf_level = teal.transform::choices_selected(c(0.95, 0.9, 0.8), 0.95,
+          keep_order =
+            TRUE
+        ),
+        pre_output = NULL,
+        post_output = NULL,
+        basic_table_args = teal.widgets::basic_table_args()
+      )
     )
   )
 }
@@ -63,7 +65,7 @@ testthat::test_that("e2e - tm_t_coxreg: Module initializes in teal without error
   app_driver$expect_no_shiny_error()
   app_driver$expect_no_validation_error()
   testthat::expect_true(
-    app_driver$is_visible(app_driver$active_module_element("table-table-with-settings"))
+    app_driver$is_visible(app_driver$namespaces(TRUE)$module("table-table-with-settings"))
   )
   app_driver$stop()
 })
@@ -150,7 +152,7 @@ testthat::test_that("e2e - tm_t_coxreg: Deselection of paramcd throws validation
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text(
+    app_driver$namespaces(TRUE)$module(
       "paramcd-dataset_ADTTE_singleextract-filter1-vals_input .shiny-validation-message"
     ),
     "An endpoint is required"
@@ -185,7 +187,7 @@ testthat::test_that("e2e - tm_t_coxreg: Deselection of arm_var throws validation
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text("arm_var-dataset_ADSL_singleextract-select_input .shiny-validation-message"),
+    app_driver$namespaces(TRUE)$module("arm_var-dataset_ADSL_singleextract-select_input .shiny-validation-message"),
     "Treatment variable must be selected"
   )
   app_driver$stop()
