@@ -12,38 +12,40 @@ app_driver_tm_t_events_by_grade <- function() { # nolint: object_length.
   teal.data::join_keys(data) <- teal.data::default_cdisc_join_keys[names(data)]
 
   init_teal_app_driver(
-    data = data,
-    modules = tm_t_events_by_grade(
-      label = "Adverse Events by Grade Table",
-      dataname = "ADAE",
-      parentname = "ADSL",
-      arm_var = teal.transform::choices_selected(c("ARM", "ARMCD"), "ARM"),
-      llt = teal.transform::choices_selected(
-        choices = teal.transform::variable_choices(data[["ADAE"]], c("AETERM", "AEDECOD")),
-        selected = c("AEDECOD")
-      ),
-      hlt = teal.transform::choices_selected(
-        choices = teal.transform::variable_choices(data[["ADAE"]], c("AEBODSYS", "AESOC")),
-        selected = "AEBODSYS"
-      ),
-      grade = teal.transform::choices_selected(
-        choices = teal.transform::variable_choices(data[["ADAE"]], c("AETOXGR", "AESEV")),
-        selected = "AETOXGR"
-      ),
-      grading_groups = list(
-        `Any Grade (%)` = c("1", "2", "3", "4", "5"), `Grade 1-2 (%)` =
-          c("1", "2"), `Grade 3-4 (%)` = c("3", "4"), `Grade 5 (%)` = "5"
-      ),
-      col_by_grade = FALSE,
-      prune_freq = 0,
-      prune_diff = 0,
-      add_total = TRUE,
-      total_label = default_total_label(),
-      na_level = default_na_str(),
-      drop_arm_levels = TRUE,
-      pre_output = NULL,
-      post_output = NULL,
-      basic_table_args = teal.widgets::basic_table_args()
+    teal::init(
+      data = data,
+      modules = tm_t_events_by_grade(
+        label = "Adverse Events by Grade Table",
+        dataname = "ADAE",
+        parentname = "ADSL",
+        arm_var = teal.transform::choices_selected(c("ARM", "ARMCD"), "ARM"),
+        llt = teal.transform::choices_selected(
+          choices = teal.transform::variable_choices(data[["ADAE"]], c("AETERM", "AEDECOD")),
+          selected = c("AEDECOD")
+        ),
+        hlt = teal.transform::choices_selected(
+          choices = teal.transform::variable_choices(data[["ADAE"]], c("AEBODSYS", "AESOC")),
+          selected = "AEBODSYS"
+        ),
+        grade = teal.transform::choices_selected(
+          choices = teal.transform::variable_choices(data[["ADAE"]], c("AETOXGR", "AESEV")),
+          selected = "AETOXGR"
+        ),
+        grading_groups = list(
+          `Any Grade (%)` = c("1", "2", "3", "4", "5"), `Grade 1-2 (%)` =
+            c("1", "2"), `Grade 3-4 (%)` = c("3", "4"), `Grade 5 (%)` = "5"
+        ),
+        col_by_grade = FALSE,
+        prune_freq = 0,
+        prune_diff = 0,
+        add_total = TRUE,
+        total_label = default_total_label(),
+        na_level = default_na_str(),
+        drop_arm_levels = TRUE,
+        pre_output = NULL,
+        post_output = NULL,
+        basic_table_args = teal.widgets::basic_table_args()
+      )
     )
   )
 }
@@ -57,7 +59,7 @@ testthat::test_that(
     app_driver$expect_no_shiny_error()
     app_driver$expect_no_validation_error()
     testthat::expect_true(
-      app_driver$is_visible(app_driver$active_module_element("table-table-with-settings"))
+      app_driver$is_visible(app_driver$namespaces(TRUE)$module("table-table-with-settings"))
     )
     app_driver$stop()
   }
@@ -132,7 +134,7 @@ testthat::test_that("e2e - tm_t_events_by_grade: Deselection of arm_var throws v
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text("arm_var-dataset_ADSL_singleextract-select_input .shiny-validation-message"),
+    app_driver$namespaces(TRUE)$module("arm_var-dataset_ADSL_singleextract-select_input .shiny-validation-message"),
     "A treatment variable is required"
   )
   app_driver$stop()
@@ -241,7 +243,7 @@ testthat::test_that("e2e - tm_t_events_by_grade: Deselection of grade throws val
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text("grade-dataset_ADAE_singleextract-select_input .shiny-validation-message"),
+    app_driver$namespaces(TRUE)$module("grade-dataset_ADAE_singleextract-select_input .shiny-validation-message"),
     "An event grade is required"
   )
   app_driver$stop()
