@@ -21,50 +21,52 @@ app_driver_tm_t_exposure <- function() {
   teal.data::join_keys(data) <- teal.data::default_cdisc_join_keys[names(data)]
 
   init_teal_app_driver(
-    data = data,
-    modules = tm_t_exposure(
-      label = "Duration of Exposure Table",
-      dataname = "ADEX",
-      parentname = "ADSL",
-      paramcd = teal.transform::choices_selected(
-        choices = teal.transform::value_choices(data[["ADEX"]], "PARAMCD", "PARAM"),
-        selected = "TDURD"
+    teal::init(
+      data = data,
+      modules = tm_t_exposure(
+        label = "Duration of Exposure Table",
+        dataname = "ADEX",
+        parentname = "ADSL",
+        paramcd = teal.transform::choices_selected(
+          choices = teal.transform::value_choices(data[["ADEX"]], "PARAMCD", "PARAM"),
+          selected = "TDURD"
+        ),
+        col_by_var = teal.transform::choices_selected(
+          choices = teal.transform::variable_choices(data[["ADEX"]], subset = c("SEX", "ARM")),
+          selected = "SEX"
+        ),
+        row_by_var = teal.transform::choices_selected(
+          choices = teal.transform::variable_choices(data[["ADEX"]], subset = c("RACE", "REGION1", "STRATA1", "SEX")),
+          selected = "RACE"
+        ),
+        parcat = teal.transform::choices_selected(
+          choices = teal.transform::value_choices(data[["ADEX"]], "PARCAT2"),
+          selected = "Drug A"
+        ),
+        add_total = FALSE,
+        paramcd_label = "PARAM",
+        id_var = teal.transform::choices_selected(
+          teal.transform::variable_choices(data[["ADEX"]], subset = "USUBJID"),
+          selected = "USUBJID", fixed = TRUE
+        ),
+        aval_var = teal.transform::choices_selected(
+          teal.transform::variable_choices(data[["ADEX"]], subset = "AVAL"),
+          selected = "AVAL", fixed = TRUE
+        ),
+        avalu_var = teal.transform::choices_selected(
+          teal.transform::variable_choices(data[["ADEX"]], subset = "AVALU"),
+          selected = "AVALU", fixed = TRUE
+        ),
+        total_label = default_total_label(),
+        add_total_row = TRUE,
+        total_row_label = "Total number of patients and patient time*",
+        na_level = default_na_str(),
+        pre_output = NULL,
+        post_output = NULL,
+        basic_table_args = teal.widgets::basic_table_args()
       ),
-      col_by_var = teal.transform::choices_selected(
-        choices = teal.transform::variable_choices(data[["ADEX"]], subset = c("SEX", "ARM")),
-        selected = "SEX"
-      ),
-      row_by_var = teal.transform::choices_selected(
-        choices = teal.transform::variable_choices(data[["ADEX"]], subset = c("RACE", "REGION1", "STRATA1", "SEX")),
-        selected = "RACE"
-      ),
-      parcat = teal.transform::choices_selected(
-        choices = teal.transform::value_choices(data[["ADEX"]], "PARCAT2"),
-        selected = "Drug A"
-      ),
-      add_total = FALSE,
-      paramcd_label = "PARAM",
-      id_var = teal.transform::choices_selected(
-        teal.transform::variable_choices(data[["ADEX"]], subset = "USUBJID"),
-        selected = "USUBJID", fixed = TRUE
-      ),
-      aval_var = teal.transform::choices_selected(
-        teal.transform::variable_choices(data[["ADEX"]], subset = "AVAL"),
-        selected = "AVAL", fixed = TRUE
-      ),
-      avalu_var = teal.transform::choices_selected(
-        teal.transform::variable_choices(data[["ADEX"]], subset = "AVALU"),
-        selected = "AVALU", fixed = TRUE
-      ),
-      total_label = default_total_label(),
-      add_total_row = TRUE,
-      total_row_label = "Total number of patients and patient time*",
-      na_level = default_na_str(),
-      pre_output = NULL,
-      post_output = NULL,
-      basic_table_args = teal.widgets::basic_table_args()
-    ),
-    filter = teal::teal_slices(teal_slice("ADSL", "SAFFL", selected = "Y")),
+      filter = teal::teal_slices(teal_slice("ADSL", "SAFFL", selected = "Y")),
+    )
   )
 }
 
@@ -75,7 +77,7 @@ testthat::test_that("e2e - tm_t_exposure: Module initializes in teal without err
   app_driver$expect_no_shiny_error()
   app_driver$expect_no_validation_error()
   testthat::expect_true(
-    app_driver$is_visible(app_driver$active_module_element("table-table-with-settings"))
+    app_driver$is_visible(app_driver$namespaces(TRUE)$module("table-table-with-settings"))
   )
   app_driver$stop()
 })
@@ -140,7 +142,7 @@ testthat::test_that("e2e - tm_t_exposure: Deselection of paramcd throws validati
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text(
+    app_driver$namespaces(TRUE)$module(
       "paramcd-dataset_ADEX_singleextract-filter1-vals_input .shiny-validation-message"
     ),
     "Please select a parameter value."
@@ -175,7 +177,7 @@ testthat::test_that("e2e - tm_t_exposure: Deselection of parcat throws validatio
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text(
+    app_driver$namespaces(TRUE)$module(
       "parcat-dataset_ADEX_singleextract-filter1-vals_input .shiny-validation-message"
     ),
     "Please select a parameter category value."
@@ -248,7 +250,7 @@ testthat::test_that("e2e - tm_t_exposure: Deselection of row_by_var throws valid
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text(
+    app_driver$namespaces(TRUE)$module(
       "row_by_var-dataset_ADEX_singleextract-select_input .shiny-validation-message"
     ),
     "Please select a row by variable."
