@@ -7,38 +7,40 @@ app_driver_tm_t_pp_laboratory <- function() {
   teal.data::join_keys(data) <- teal.data::default_cdisc_join_keys[names(data)]
 
   init_teal_app_driver(
-    data = data,
-    modules = tm_t_pp_laboratory(
-      label = "Vitals",
-      dataname = "ADLB",
-      parentname = "ADSL",
-      patient_col = "USUBJID",
-      paramcd = teal.transform::choices_selected(
-        choices = teal.transform::variable_choices(data[["ADLB"]], c("PARAMCD", "STUDYID")),
-        selected = "PARAMCD"
-      ),
-      param = teal.transform::choices_selected(
-        choices = teal.transform::variable_choices(data[["ADLB"]], c("PARAM", "SEX")),
-        selected = "PARAM"
-      ),
-      timepoints = teal.transform::choices_selected(
-        choices = teal.transform::variable_choices(data[["ADLB"]], c("ADY", "AGE")),
-        selected = "ADY"
-      ),
-      anrind = teal.transform::choices_selected(
-        choices = teal.transform::variable_choices(data[["ADLB"]], c("ANRIND", "AGEU")),
-        selected = "ANRIND"
-      ),
-      aval_var = teal.transform::choices_selected(
-        choices = teal.transform::variable_choices(data[["ADLB"]], c("AVAL", "AGE")),
-        selected = "AVAL"
-      ),
-      avalu_var = teal.transform::choices_selected(
-        choices = teal.transform::variable_choices(data[["ADLB"]], c("AVALU", "SEX")),
-        selected = "AVALU"
-      ),
-      pre_output = NULL,
-      post_output = NULL
+    teal::init(
+      data = data,
+      modules = tm_t_pp_laboratory(
+        label = "Vitals",
+        dataname = "ADLB",
+        parentname = "ADSL",
+        patient_col = "USUBJID",
+        paramcd = teal.transform::choices_selected(
+          choices = teal.transform::variable_choices(data[["ADLB"]], c("PARAMCD", "STUDYID")),
+          selected = "PARAMCD"
+        ),
+        param = teal.transform::choices_selected(
+          choices = teal.transform::variable_choices(data[["ADLB"]], c("PARAM", "SEX")),
+          selected = "PARAM"
+        ),
+        timepoints = teal.transform::choices_selected(
+          choices = teal.transform::variable_choices(data[["ADLB"]], c("ADY", "AGE")),
+          selected = "ADY"
+        ),
+        anrind = teal.transform::choices_selected(
+          choices = teal.transform::variable_choices(data[["ADLB"]], c("ANRIND", "AGEU")),
+          selected = "ANRIND"
+        ),
+        aval_var = teal.transform::choices_selected(
+          choices = teal.transform::variable_choices(data[["ADLB"]], c("AVAL", "AGE")),
+          selected = "AVAL"
+        ),
+        avalu_var = teal.transform::choices_selected(
+          choices = teal.transform::variable_choices(data[["ADLB"]], c("AVALU", "SEX")),
+          selected = "AVALU"
+        ),
+        pre_output = NULL,
+        post_output = NULL
+      )
     )
   )
 }
@@ -50,7 +52,7 @@ testthat::test_that("e2e - tm_t_pp_laboratory: Module initializes in teal withou
   app_driver$expect_no_shiny_error()
   app_driver$expect_no_validation_error()
   testthat::expect_true(
-    app_driver$is_visible(app_driver$active_module_element("lab_values_table"))
+    app_driver$is_visible(app_driver$namespaces(TRUE)$module("lab_values_table"))
   )
   app_driver$stop()
 })
@@ -129,13 +131,13 @@ testthat::test_that("e2e - tm_t_pp_laboratory: Deselection of patient_id throws
   app_driver$set_active_module_input("patient_id", NULL)
   testthat::expect_false(
     app_driver$is_visible(
-      app_driver$active_module_element("lab_values_table"),
+      app_driver$namespaces(TRUE)$module("lab_values_table"),
       visibility_property = TRUE
     )
   )
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text("patient_id_input .shiny-validation-message"),
+    app_driver$namespaces(TRUE)$module("patient_id_input .shiny-validation-message"),
     "Please select a patient"
   )
   app_driver$stop()
@@ -168,13 +170,13 @@ testthat::test_that("e2e - tm_t_pp_laboratory: Deselection of paramcd throws val
   app_driver$set_active_module_input("paramcd-dataset_ADLB_singleextract-select", NULL)
   testthat::expect_false(
     app_driver$is_visible(
-      app_driver$active_module_element("lab_values_table"),
+      app_driver$namespaces(TRUE)$module("lab_values_table"),
       visibility_property = TRUE
     )
   )
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text("paramcd-dataset_ADLB_singleextract-select_input .shiny-validation-message"),
+    app_driver$namespaces(TRUE)$module("paramcd-dataset_ADLB_singleextract-select_input .shiny-validation-message"),
     "Please select PARAMCD variable."
   )
   app_driver$stop()
@@ -209,13 +211,13 @@ testthat::test_that(
     app_driver$set_active_module_input("param-dataset_ADLB_singleextract-select", NULL)
     testthat::expect_false(
       app_driver$is_visible(
-        app_driver$active_module_element("lab_values_table"),
+        app_driver$namespaces(TRUE)$module("lab_values_table"),
         visibility_property = TRUE
       )
     )
     app_driver$expect_validation_error()
     testthat::expect_equal(
-      app_driver$active_module_element_text("param-dataset_ADLB_singleextract-select_input .shiny-validation-message"),
+      app_driver$namespaces(TRUE)$module("param-dataset_ADLB_singleextract-select_input .shiny-validation-message"),
       "Please select PARAM variable."
     )
     app_driver$stop()
@@ -249,13 +251,13 @@ testthat::test_that("e2e - tm_t_pp_laboratory: Deselection of timepoints throws
   app_driver$set_active_module_input("timepoints-dataset_ADLB_singleextract-select", NULL)
   testthat::expect_false(
     app_driver$is_visible(
-      app_driver$active_module_element("lab_values_table"),
+      app_driver$namespaces(TRUE)$module("lab_values_table"),
       visibility_property = TRUE
     )
   )
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text(
+    app_driver$namespaces(TRUE)$module(
       "timepoints-dataset_ADLB_singleextract-select_input .shiny-validation-message"
     ),
     "Please select timepoints variable."
@@ -290,13 +292,13 @@ testthat::test_that("e2e - tm_t_pp_laboratory: Deselection of avalu throws valid
   app_driver$set_active_module_input("avalu_var-dataset_ADLB_singleextract-select", NULL)
   testthat::expect_false(
     app_driver$is_visible(
-      app_driver$active_module_element("lab_values_table"),
+      app_driver$namespaces(TRUE)$module("lab_values_table"),
       visibility_property = TRUE
     )
   )
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text(
+    app_driver$namespaces(TRUE)$module(
       "avalu_var-dataset_ADLB_singleextract-select_input .shiny-validation-message"
     ),
     "Please select AVALU variable."
@@ -331,13 +333,13 @@ testthat::test_that("e2e - tm_t_pp_laboratory: Deselection of aval_var throws va
   app_driver$set_active_module_input("aval_var-dataset_ADLB_singleextract-select", NULL)
   testthat::expect_false(
     app_driver$is_visible(
-      app_driver$active_module_element("lab_values_table"),
+      app_driver$namespaces(TRUE)$module("lab_values_table"),
       visibility_property = TRUE
     )
   )
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text("aval_var-dataset_ADLB_singleextract-select_input .shiny-validation-message"),
+    app_driver$namespaces(TRUE)$module("aval_var-dataset_ADLB_singleextract-select_input .shiny-validation-message"),
     "Please select AVAL variable."
   )
   app_driver$stop()
@@ -370,13 +372,13 @@ testthat::test_that("e2e - tm_t_pp_laboratory: Deselection of arind throws valid
   app_driver$set_active_module_input("anrind-dataset_ADLB_singleextract-select", NULL)
   testthat::expect_false(
     app_driver$is_visible(
-      app_driver$active_module_element("lab_values_table"),
+      app_driver$namespaces(TRUE)$module("lab_values_table"),
       visibility_property = TRUE
     )
   )
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text("anrind-dataset_ADLB_singleextract-select_input .shiny-validation-message"),
+    app_driver$namespaces(TRUE)$module("anrind-dataset_ADLB_singleextract-select_input .shiny-validation-message"),
     "Please select ANRIND variable."
   )
   app_driver$stop()
