@@ -7,26 +7,28 @@ app_driver_tm_t_pp_medical_history <- function() { # nolint: object_length.
   teal.data::join_keys(data) <- teal.data::default_cdisc_join_keys[names(data)]
 
   init_teal_app_driver(
-    data = data,
-    modules = tm_t_pp_medical_history(
-      label = "Medical History",
-      dataname = "ADMH",
-      parentname = "ADSL",
-      patient_col = "USUBJID",
-      mhterm = teal.transform::choices_selected(
-        choices = teal.transform::variable_choices(data[["ADMH"]], c("MHTERM", "STUDYID")),
-        selected = "MHTERM"
-      ),
-      mhbodsys = teal.transform::choices_selected(
-        choices = teal.transform::variable_choices(data[["ADMH"]], c("MHBODSYS", "EOSSTT")),
-        selected = "MHBODSYS"
-      ),
-      mhdistat = teal.transform::choices_selected(
-        choices = teal.transform::variable_choices(data[["ADMH"]], c("MHDISTAT", "STUDYID")),
-        selected = "MHDISTAT"
-      ),
-      pre_output = NULL,
-      post_output = NULL
+    teal::init(
+      data = data,
+      modules = tm_t_pp_medical_history(
+        label = "Medical History",
+        dataname = "ADMH",
+        parentname = "ADSL",
+        patient_col = "USUBJID",
+        mhterm = teal.transform::choices_selected(
+          choices = teal.transform::variable_choices(data[["ADMH"]], c("MHTERM", "STUDYID")),
+          selected = "MHTERM"
+        ),
+        mhbodsys = teal.transform::choices_selected(
+          choices = teal.transform::variable_choices(data[["ADMH"]], c("MHBODSYS", "EOSSTT")),
+          selected = "MHBODSYS"
+        ),
+        mhdistat = teal.transform::choices_selected(
+          choices = teal.transform::variable_choices(data[["ADMH"]], c("MHDISTAT", "STUDYID")),
+          selected = "MHDISTAT"
+        ),
+        pre_output = NULL,
+        post_output = NULL
+      )
     )
   )
 }
@@ -40,7 +42,7 @@ testthat::test_that(
     app_driver$expect_no_shiny_error()
     app_driver$expect_no_validation_error()
     testthat::expect_true(
-      app_driver$is_visible(app_driver$active_module_element("table-table-with-settings"))
+      app_driver$is_visible(app_driver$namespaces(TRUE)$module("table-table-with-settings"))
     )
     app_driver$stop()
   }
@@ -104,7 +106,7 @@ testthat::test_that("e2e - tm_t_pp_medical_history: Deselection of patient_id th
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text("patient_id_input .shiny-validation-message"),
+    app_driver$namespaces(TRUE)$module("patient_id_input .shiny-validation-message"),
     "Please select a patient"
   )
   app_driver$stop()
@@ -137,7 +139,7 @@ testthat::test_that("e2e - tm_t_pp_medical_history: Deselection of mhterm throws
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text("mhterm-dataset_ADMH_singleextract-select_input .shiny-validation-message"),
+    app_driver$namespaces(TRUE)$module("mhterm-dataset_ADMH_singleextract-select_input .shiny-validation-message"),
     "Please select MHTERM variable."
   )
   app_driver$stop()
@@ -170,7 +172,7 @@ testthat::test_that("e2e - tm_t_pp_medical_history: Deselection of mhbodsys thro
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text("mhbodsys-dataset_ADMH_singleextract-select_input .shiny-validation-message"),
+    app_driver$namespaces(TRUE)$module("mhbodsys-dataset_ADMH_singleextract-select_input .shiny-validation-message"),
     "Please select MHBODSYS variable."
   )
   app_driver$stop()
@@ -203,7 +205,7 @@ testthat::test_that("e2e - tm_t_pp_medical_history: Deselection of mhdistat thro
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text("mhdistat-dataset_ADMH_singleextract-select_input .shiny-validation-message"),
+    app_driver$namespaces(TRUE)$module("mhdistat-dataset_ADMH_singleextract-select_input .shiny-validation-message"),
     "Please select MHDISTAT variable."
   )
   app_driver$stop()
