@@ -7,43 +7,45 @@ app_driver_tm_t_shift_by_arm <- function() {
   teal.data::join_keys(data) <- teal.data::default_cdisc_join_keys[names(data)]
 
   init_teal_app_driver(
-    data = data,
-    modules = tm_t_shift_by_arm(
-      label = "Shift by Arm Table",
-      dataname = "ADEG",
-      parentname = "ADSL",
-      arm_var = teal.transform::choices_selected(
-        teal.transform::variable_choices(data[["ADSL"]], subset = c("ARM", "ARMCD")),
-        selected = "ARM"
-      ),
-      paramcd = teal.transform::choices_selected(
-        teal.transform::value_choices(data[["ADEG"]], "PARAMCD"),
-        selected = "HR"
-      ),
-      visit_var = teal.transform::choices_selected(
-        teal.transform::value_choices(data[["ADEG"]], "AVISIT"),
-        selected = "POST-BASELINE MINIMUM"
-      ),
-      aval_var = teal.transform::choices_selected(
-        teal.transform::variable_choices(data[["ADEG"]], subset = "ANRIND"),
-        selected = "ANRIND", fixed = TRUE
-      ),
-      baseline_var = teal.transform::choices_selected(
-        teal.transform::variable_choices(data[["ADEG"]], subset = "BNRIND"),
-        selected = "BNRIND", fixed = TRUE
-      ),
-      useNA = "ifany",
-      treatment_flag_var = teal.transform::choices_selected(
-        teal.transform::variable_choices(data[["ADEG"]], subset = "ONTRTFL"),
-        selected = "ONTRTFL"
-      ),
-      treatment_flag = teal.transform::choices_selected("Y"),
-      na_level = default_na_str(),
-      add_total = FALSE,
-      total_label = default_total_label(),
-      pre_output = NULL,
-      post_output = NULL,
-      basic_table_args = teal.widgets::basic_table_args()
+    teal::init(
+      data = data,
+      modules = tm_t_shift_by_arm(
+        label = "Shift by Arm Table",
+        dataname = "ADEG",
+        parentname = "ADSL",
+        arm_var = teal.transform::choices_selected(
+          teal.transform::variable_choices(data[["ADSL"]], subset = c("ARM", "ARMCD")),
+          selected = "ARM"
+        ),
+        paramcd = teal.transform::choices_selected(
+          teal.transform::value_choices(data[["ADEG"]], "PARAMCD"),
+          selected = "HR"
+        ),
+        visit_var = teal.transform::choices_selected(
+          teal.transform::value_choices(data[["ADEG"]], "AVISIT"),
+          selected = "POST-BASELINE MINIMUM"
+        ),
+        aval_var = teal.transform::choices_selected(
+          teal.transform::variable_choices(data[["ADEG"]], subset = "ANRIND"),
+          selected = "ANRIND", fixed = TRUE
+        ),
+        baseline_var = teal.transform::choices_selected(
+          teal.transform::variable_choices(data[["ADEG"]], subset = "BNRIND"),
+          selected = "BNRIND", fixed = TRUE
+        ),
+        useNA = "ifany",
+        treatment_flag_var = teal.transform::choices_selected(
+          teal.transform::variable_choices(data[["ADEG"]], subset = "ONTRTFL"),
+          selected = "ONTRTFL"
+        ),
+        treatment_flag = teal.transform::choices_selected("Y"),
+        na_level = default_na_str(),
+        add_total = FALSE,
+        total_label = default_total_label(),
+        pre_output = NULL,
+        post_output = NULL,
+        basic_table_args = teal.widgets::basic_table_args()
+      )
     )
   )
 }
@@ -55,7 +57,7 @@ testthat::test_that("e2e - tm_t_shift_by_arm: Module initializes in teal without
   app_driver$expect_no_shiny_error()
   app_driver$expect_no_validation_error()
   testthat::expect_true(
-    app_driver$is_visible(app_driver$active_module_element("table-table-with-settings"))
+    app_driver$is_visible(app_driver$namespaces(TRUE)$module("table-table-with-settings"))
   )
   app_driver$stop()
 })
@@ -123,7 +125,7 @@ testthat::test_that("e2e - tm_t_shift_by_arm: Deselection of arm_var throws vali
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text("arm_var-dataset_ADSL_singleextract-select_input .shiny-validation-message"),
+    app_driver$namespaces(TRUE)$module("arm_var-dataset_ADSL_singleextract-select_input .shiny-validation-message"),
     "A treatment variable is required"
   )
   app_driver$stop()
@@ -156,7 +158,7 @@ testthat::test_that("e2e - tm_t_shift_by_arm: Deselection of paramcd throws vali
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text(
+    app_driver$namespaces(TRUE)$module(
       "paramcd-dataset_ADEG_singleextract-filter1-vals_input .shiny-validation-message"
     ),
     "An endpoint is required"
@@ -191,7 +193,7 @@ testthat::test_that("e2e - tm_t_shift_by_arm: Deselection of visit_var throws va
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text(
+    app_driver$namespaces(TRUE)$module(
       "visit_var-dataset_ADEG_singleextract-filter1-vals_input .shiny-validation-message"
     ),
     "A visit is required"
