@@ -7,43 +7,45 @@ app_driver_tm_t_shift_by_arm_by_worst <- function() { # nolint: object_length.
   teal.data::join_keys(data) <- teal.data::default_cdisc_join_keys[names(data)]
 
   init_teal_app_driver(
-    data = data,
-    modules = tm_t_shift_by_arm_by_worst(
-      label = "Shift by Arm Table",
-      dataname = "ADEG",
-      parentname = "ADSL",
-      arm_var = teal.transform::choices_selected(
-        teal.transform::variable_choices(data[["ADSL"]], subset = c("ARM", "ARMCD")),
-        selected = "ARM"
-      ),
-      paramcd = teal.transform::choices_selected(
-        teal.transform::value_choices(data[["ADEG"]], "PARAMCD"),
-        selected = "ECGINTP"
-      ),
-      worst_flag_var = teal.transform::choices_selected(
-        teal.transform::variable_choices(data[["ADEG"]], c("WORS02FL", "WORS01FL")),
-        selected = "WORS02FL"
-      ),
-      worst_flag = teal.transform::choices_selected(
-        teal.transform::value_choices(data[["ADEG"]], "WORS02FL"),
-        selected = "Y", fixed = TRUE
-      ),
-      aval_var = teal.transform::choices_selected(
-        teal.transform::variable_choices(data[["ADEG"]], c("REGION1", "AVALC")),
-        selected = "REGION1"
-      ),
-      baseline_var = teal.transform::choices_selected(
-        teal.transform::variable_choices(data[["ADEG"]], c("AVISIT", "BASEC")),
-        selected = "AVISIT"
-      ),
-      useNA = "ifany",
-      treatment_flag = teal.transform::choices_selected("Y"),
-      na_level = default_na_str(),
-      add_total = FALSE,
-      total_label = default_total_label(),
-      pre_output = NULL,
-      post_output = NULL,
-      basic_table_args = teal.widgets::basic_table_args()
+    teal::init(
+      data = data,
+      modules = tm_t_shift_by_arm_by_worst(
+        label = "Shift by Arm Table",
+        dataname = "ADEG",
+        parentname = "ADSL",
+        arm_var = teal.transform::choices_selected(
+          teal.transform::variable_choices(data[["ADSL"]], subset = c("ARM", "ARMCD")),
+          selected = "ARM"
+        ),
+        paramcd = teal.transform::choices_selected(
+          teal.transform::value_choices(data[["ADEG"]], "PARAMCD"),
+          selected = "ECGINTP"
+        ),
+        worst_flag_var = teal.transform::choices_selected(
+          teal.transform::variable_choices(data[["ADEG"]], c("WORS02FL", "WORS01FL")),
+          selected = "WORS02FL"
+        ),
+        worst_flag = teal.transform::choices_selected(
+          teal.transform::value_choices(data[["ADEG"]], "WORS02FL"),
+          selected = "Y", fixed = TRUE
+        ),
+        aval_var = teal.transform::choices_selected(
+          teal.transform::variable_choices(data[["ADEG"]], c("REGION1", "AVALC")),
+          selected = "REGION1"
+        ),
+        baseline_var = teal.transform::choices_selected(
+          teal.transform::variable_choices(data[["ADEG"]], c("AVISIT", "BASEC")),
+          selected = "AVISIT"
+        ),
+        useNA = "ifany",
+        treatment_flag = teal.transform::choices_selected("Y"),
+        na_level = default_na_str(),
+        add_total = FALSE,
+        total_label = default_total_label(),
+        pre_output = NULL,
+        post_output = NULL,
+        basic_table_args = teal.widgets::basic_table_args()
+      )
     )
   )
 }
@@ -57,7 +59,7 @@ testthat::test_that(
     app_driver$expect_no_shiny_error()
     app_driver$expect_no_validation_error()
     testthat::expect_true(
-      app_driver$is_visible(app_driver$active_module_element("table-table-with-settings"))
+      app_driver$is_visible(app_driver$namespaces(TRUE)$module("table-table-with-settings"))
     )
     app_driver$stop()
   }
@@ -136,7 +138,7 @@ testthat::test_that("e2e - tm_t_shift_by_arm_by_worst: Deselection of arm_var th
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text("arm_var-dataset_ADSL_singleextract-select_input .shiny-validation-message"),
+    app_driver$namespaces(TRUE)$module("arm_var-dataset_ADSL_singleextract-select_input .shiny-validation-message"),
     "A treatment variable is required"
   )
   app_driver$stop()
@@ -169,7 +171,7 @@ testthat::test_that("e2e - tm_t_shift_by_arm_by_worst: Deselection of paramcd th
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text(
+    app_driver$namespaces(TRUE)$module(
       "paramcd-dataset_ADEG_singleextract-filter1-vals_input .shiny-validation-message"
     ),
     "An endpoint is required"
@@ -205,7 +207,7 @@ testthat::test_that("e2e - tm_t_shift_by_arm_by_worst: Deselection of worst_flag
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text(
+    app_driver$namespaces(TRUE)$module(
       "worst_flag_var-dataset_ADEG_singleextract-select_input .shiny-validation-message"
     ),
     "A worst flag variable is required"
@@ -241,7 +243,7 @@ testthat::test_that("e2e - tm_t_shift_by_arm_by_worst: Deselection of aval_var t
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text("aval_var-dataset_ADEG_singleextract-select_input .shiny-validation-message"),
+    app_driver$namespaces(TRUE)$module("aval_var-dataset_ADEG_singleextract-select_input .shiny-validation-message"),
     "An analysis range indicator required"
   )
   app_driver$stop()
@@ -275,7 +277,7 @@ testthat::test_that("e2e - tm_t_shift_by_arm_by_worst: Deselection of baseline_v
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text(
+    app_driver$namespaces(TRUE)$module(
       "baseline_var-dataset_ADEG_singleextract-select_input .shiny-validation-message"
     ),
     "A baseline reference range indicator is required"
