@@ -6,29 +6,31 @@ app_driver_tm_t_summary <- function() {
   teal.data::join_keys(data) <- teal.data::default_cdisc_join_keys[names(data)]
 
   init_teal_app_driver(
-    data = data,
-    modules = tm_t_summary(
-      label = "Demographic Table",
-      dataname = "ADSL",
-      arm_var = teal.transform::choices_selected(c("ARM", "ARMCD"), "ARM"),
-      add_total = TRUE,
-      summarize_vars = teal.transform::choices_selected(
-        c("SEX", "RACE", "BMRKR2", "EOSDY", "DCSREAS", "AGE"),
-        c("SEX", "RACE")
-      ),
-      useNA = "ifany",
-      parentname = "ADSL",
-      total_label = default_total_label(),
-      na_level = default_na_str(),
-      numeric_stats = c(
-        "n", "mean_sd", "mean_ci", "median", "median_ci", "quantiles",
-        "range", "geom_mean"
-      ),
-      denominator = c("N", "n", "omit"),
-      drop_arm_levels = TRUE,
-      pre_output = NULL,
-      post_output = NULL,
-      basic_table_args = teal.widgets::basic_table_args()
+    teal::init(
+      data = data,
+      modules = tm_t_summary(
+        label = "Demographic Table",
+        dataname = "ADSL",
+        arm_var = teal.transform::choices_selected(c("ARM", "ARMCD"), "ARM"),
+        add_total = TRUE,
+        summarize_vars = teal.transform::choices_selected(
+          c("SEX", "RACE", "BMRKR2", "EOSDY", "DCSREAS", "AGE"),
+          c("SEX", "RACE")
+        ),
+        useNA = "ifany",
+        parentname = "ADSL",
+        total_label = default_total_label(),
+        na_level = default_na_str(),
+        numeric_stats = c(
+          "n", "mean_sd", "mean_ci", "median", "median_ci", "quantiles",
+          "range", "geom_mean"
+        ),
+        denominator = c("N", "n", "omit"),
+        drop_arm_levels = TRUE,
+        pre_output = NULL,
+        post_output = NULL,
+        basic_table_args = teal.widgets::basic_table_args()
+      )
     )
   )
 }
@@ -40,7 +42,7 @@ testthat::test_that("e2e - tm_t_summary: Module initializes in teal without erro
   app_driver$expect_no_shiny_error()
   app_driver$expect_no_validation_error()
   testthat::expect_true(
-    app_driver$is_visible(app_driver$active_module_element("table-table-with-settings"))
+    app_driver$is_visible(app_driver$namespaces(TRUE)$module("table-table-with-settings"))
   )
   app_driver$stop()
 })
@@ -99,7 +101,7 @@ testthat::test_that("e2e - tm_t_summary: Deselection of arm_var throws validatio
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text("arm_var-dataset_ADSL_singleextract-select_input .shiny-validation-message"),
+    app_driver$namespaces(TRUE)$module("arm_var-dataset_ADSL_singleextract-select_input .shiny-validation-message"),
     "Please select 1 or 2 column variables"
   )
   app_driver$stop()
@@ -132,7 +134,7 @@ testthat::test_that("e2e - tm_t_summary: Deselection of summarize_vars throws va
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text(
+    app_driver$namespaces(TRUE)$module(
       "summarize_vars-dataset_ADSL_singleextract-select_input .shiny-validation-message"
     ),
     "Please select a summarize variable"
