@@ -7,46 +7,48 @@ app_driver_tm_t_summary_by <- function() {
   teal.data::join_keys(data) <- teal.data::default_cdisc_join_keys[names(data)]
 
   init_teal_app_driver(
-    data = data,
-    modules = tm_t_summary_by(
-      label = "Summary by Row Groups Table",
-      dataname = "ADLB",
-      parentname = "ADSL",
-      arm_var = teal.transform::choices_selected(
-        choices = teal.transform::variable_choices(data[["ADSL"]], c("ARM", "ARMCD")),
-        selected = "ARM"
-      ),
-      add_total = TRUE,
-      by_vars = teal.transform::choices_selected(
-        choices = teal.transform::variable_choices(data[["ADLB"]], c("PARAM", "AVISIT")),
-        selected = c("AVISIT")
-      ),
-      summarize_vars = teal.transform::choices_selected(
-        choices = teal.transform::variable_choices(data[["ADLB"]], c("AVAL", "CHG")),
-        selected = c("AVAL")
-      ),
-      useNA = "ifany",
-      paramcd = teal.transform::choices_selected(
-        choices = teal.transform::value_choices(data[["ADLB"]], "PARAMCD", "PARAM"),
-        selected = "ALT"
-      ),
-      id_var = teal.transform::choices_selected(
-        teal.transform::variable_choices(data[["ADLB"]], subset = "USUBJID"),
-        selected = "USUBJID", fixed = TRUE
-      ),
-      total_label = default_total_label(),
-      parallel_vars = FALSE,
-      row_groups = FALSE,
-      na_level = default_na_str(),
-      numeric_stats = c("n", "mean_sd", "median", "range"),
-      denominator = teal.transform::choices_selected(c("n", "N", "omit"), "omit",
-        fixed = TRUE
-      ),
-      drop_arm_levels = TRUE,
-      drop_zero_levels = TRUE,
-      pre_output = NULL,
-      post_output = NULL,
-      basic_table_args = teal.widgets::basic_table_args()
+    teal::init(
+      data = data,
+      modules = tm_t_summary_by(
+        label = "Summary by Row Groups Table",
+        dataname = "ADLB",
+        parentname = "ADSL",
+        arm_var = teal.transform::choices_selected(
+          choices = teal.transform::variable_choices(data[["ADSL"]], c("ARM", "ARMCD")),
+          selected = "ARM"
+        ),
+        add_total = TRUE,
+        by_vars = teal.transform::choices_selected(
+          choices = teal.transform::variable_choices(data[["ADLB"]], c("PARAM", "AVISIT")),
+          selected = c("AVISIT")
+        ),
+        summarize_vars = teal.transform::choices_selected(
+          choices = teal.transform::variable_choices(data[["ADLB"]], c("AVAL", "CHG")),
+          selected = c("AVAL")
+        ),
+        useNA = "ifany",
+        paramcd = teal.transform::choices_selected(
+          choices = teal.transform::value_choices(data[["ADLB"]], "PARAMCD", "PARAM"),
+          selected = "ALT"
+        ),
+        id_var = teal.transform::choices_selected(
+          teal.transform::variable_choices(data[["ADLB"]], subset = "USUBJID"),
+          selected = "USUBJID", fixed = TRUE
+        ),
+        total_label = default_total_label(),
+        parallel_vars = FALSE,
+        row_groups = FALSE,
+        na_level = default_na_str(),
+        numeric_stats = c("n", "mean_sd", "median", "range"),
+        denominator = teal.transform::choices_selected(c("n", "N", "omit"), "omit",
+          fixed = TRUE
+        ),
+        drop_arm_levels = TRUE,
+        drop_zero_levels = TRUE,
+        pre_output = NULL,
+        post_output = NULL,
+        basic_table_args = teal.widgets::basic_table_args()
+      )
     )
   )
 }
@@ -58,7 +60,7 @@ testthat::test_that("e2e - tm_t_summary_by: Module initializes in teal without e
   app_driver$expect_no_shiny_error()
   app_driver$expect_no_validation_error()
   testthat::expect_true(
-    app_driver$is_visible(app_driver$active_module_element("table-table-with-settings"))
+    app_driver$is_visible(app_driver$namespaces(TRUE)$module("table-table-with-settings"))
   )
   app_driver$stop()
 })
@@ -133,7 +135,7 @@ testthat::test_that("e2e - tm_t_summary_by: Deselection of arm_var throws valida
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text("arm_var-dataset_ADSL_singleextract-select_input .shiny-validation-message"),
+    app_driver$namespaces(TRUE)$module("arm_var-dataset_ADSL_singleextract-select_input .shiny-validation-message"),
     "Please select 1 or 2 column variables"
   )
   app_driver$stop()
@@ -166,7 +168,7 @@ testthat::test_that("e2e - tm_t_summary_by: Deselection of arm_var throws valida
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text(
+    app_driver$namespaces(TRUE)$module(
       "paramcd-dataset_ADLB_singleextract-filter1-vals_input .shiny-validation-message"
     ),
     "Please select a filter."
@@ -239,7 +241,7 @@ testthat::test_that("e2e - tm_t_summary_by: Deselection of summarize_vars throws
   testthat::expect_identical(app_driver$get_active_module_table_output("table-table-with-settings"), data.frame())
   app_driver$expect_validation_error()
   testthat::expect_equal(
-    app_driver$active_module_element_text(
+    app_driver$namespaces(TRUE)$module(
       "summarize_vars-dataset_ADLB_singleextract-select_input .shiny-validation-message"
     ),
     "Please select a summarize variable."
